#!/usr/bin/python3
"""Integration tests for v3i translations resolvers validating country, year, and combined formatters."""

import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar
from ArWikiCats.new_resolvers.translations_resolvers_v3i.resolve_v3i import resolve_year_job_from_countries

test_0 = {
    "18th-century writers from Safavid Iran": "كتاب من إيران الصفوية في القرن 18",
    "18th-century people from Safavid Iran": "أشخاص من إيران الصفوية في القرن 18",
    "17th-century writers from Safavid Iran": "كتاب من إيران الصفوية في القرن 17",
    "17th-century people from Safavid Iran": "أشخاص من إيران الصفوية في القرن 17",
    "16th-century writers from Safavid Iran": "كتاب من إيران الصفوية في القرن 16",
    "16th-century people from Safavid Iran": "أشخاص من إيران الصفوية في القرن 16",
    "10th-century people from Ifriqiya": "تونسيون في القرن 10",
    "11th-century people from Ifriqiya": "تونسيون في القرن 11",
    "12th-century people from Ifriqiya": "تونسيون في القرن 12",
    "13th-century people from ifriqiya": "تونسيون في القرن 13",
    "14th-century people from Ifriqiya": "تونسيون في القرن 14",
    "15th-century people from Ifriqiya": "تونسيون في القرن 15",
    "9th-century people from Ifriqiya": "تونسيون في القرن 9",
    "21st-century people from Northern Ireland by occupation": "أشخاص من أيرلندا الشمالية حسب المهنة في القرن 21",
    "21st-century people from Georgia (country) by occupation": "أشخاص من جورجيا في القرن 21 حسب المهنة",
    "20th-century people from Northern Ireland by occupation": "أشخاص من أيرلندا الشمالية حسب المهنة في القرن 20",
    "20th-century people from Georgia (country) by occupation": "أشخاص من جورجيا في القرن 20 حسب المهنة",
    "19th-century people from the Ottoman Empire by conflict": "أشخاص من الدولة العثمانية في القرن 19 حسب النزاع",
    "19th-century people from the Russian Empire by occupation": "روس في القرن 19 حسب المهنة",
    "19th-century people from Ottoman Iraq by occupation": "عراقيون في القرن 19 حسب المهنة",
    "19th-century people from Georgia (country) by occupation": "أشخاص من جورجيا في القرن 19 حسب المهنة",
    "18th-century people from the Polish–Lithuanian Commonwealth by occupation": "أشخاص بولنديون في القرن 18 حسب المهنة",
    "18th-century people from the Russian Empire by occupation": "روس في القرن 18 حسب المهنة",
    "17th-century politicians from the Province of New York": "سياسيو ولاية نيويورك القرن 17",
    "14th-century deaths from plague (disease)": "وفيات القرن 14 بسبب الطاعون",
    "11th-century people from the Savoyard State": "أشخاص من منطقة سافوا في القرن 11",
    "16th-century people from the Colony of Santo Domingo": "دومينيكانيون في القرن 16",
    "17th-century people from the Colony of Santo Domingo": "دومينيكانيون في القرن 17",
    "17th-century people from the Province of New York": "أشخاص من ولاية نيويورك في القرن 17",
    "18th-century people from the Savoyard State": "أشخاص من منطقة سافوا في القرن 18",
}

test_data_1 = {
    "17th-century philosophers from the Holy Roman Empire": "فلاسفة من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century philosophers from the Holy Roman Empire": "فلاسفة من الإمبراطورية الرومانية المقدسة في القرن 18",
    "15th-century physicians from the Holy Roman Empire": "أطباء من الإمبراطورية الرومانية المقدسة في القرن 15",
    "16th-century physicians from the Holy Roman Empire": "أطباء من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century physicians from the Holy Roman Empire": "أطباء من الإمبراطورية الرومانية المقدسة في القرن 17",
    "10th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 10",
    "11th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 11",
    "12th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 12",
    "13th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 13",
    "14th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 14",
    "15th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 15",
    "16th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 18",
    "15th-century painters from the Holy Roman Empire": "رسامون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "16th-century painters from the Holy Roman Empire": "رسامون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century painters from the Holy Roman Empire": "رسامون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century painters from the Holy Roman Empire": "رسامون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "13th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 13",
    "14th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 14",
    "17th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 18",
    "16th-century musicians from the Holy Roman Empire": "موسيقيون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century musicians from the Holy Roman Empire": "موسيقيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century musicians from the Holy Roman Empire": "موسيقيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century male actors from the Holy Roman Empire": "ممثلون ذكور من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century male singers from the Holy Roman Empire": "مغنون ذكور من الإمبراطورية الرومانية المقدسة في القرن 18",
    "15th-century mathematicians from the Holy Roman Empire": "رياضياتيون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "16th-century mathematicians from the Holy Roman Empire": "رياضياتيون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century mathematicians from the Holy Roman Empire": "رياضياتيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century mathematicians from the Holy Roman Empire": "رياضياتيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "15th-century jurists from the Holy Roman Empire": "حقوقيون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "16th-century jurists from the Holy Roman Empire": "حقوقيون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century jurists from the Holy Roman Empire": "حقوقيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century jurists from the Holy Roman Empire": "حقوقيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "16th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "11th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 11",
    "12th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 12",
    "14th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 14",
    "15th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "12th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 12",
    "13th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 13",
    "14th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 14",
    "15th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 15",
    "16th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century violinists from the Holy Roman Empire": "عازفو كمان من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century women singers from the Holy Roman Empire": "مغنيات من الإمبراطورية الرومانية المقدسة في القرن 18",
    "17th-century singers from the Holy Roman Empire": "مغنون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century singers from the Holy Roman Empire": "مغنون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "13th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 13",
    "14th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 14",
    "15th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 15",
    "16th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 18",
    "16th-century sculptors from the Holy Roman Empire": "نحاتون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "18th-century sculptors from the Holy Roman Empire": "نحاتون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "16th-century scholars from the Holy Roman Empire": "دارسون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century scholars from the Holy Roman Empire": "دارسون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century scholars from the Holy Roman Empire": "دارسون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "17th-century politicians from the Holy Roman Empire": "سياسيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century politicians from the Holy Roman Empire": "سياسيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "17th-century publishers (people) from the Holy Roman Empire": "ناشرون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century publishers (people) from the Holy Roman Empire": "ناشرون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "10th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 10",
    "11th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 11",
    "12th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 12",
    "13th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 13",
    "14th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 14",
    "15th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 15",
    "16th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 18",
    "19th-century poets from Ottoman Iraq": "شعراء من العراق العثماني في القرن 19",
    "19th-century people from Ottoman Arabia": "أشخاص من الدولة العثمانية في شبه الجزيرة العربية في القرن 19",
    "20th-century non-fiction writers from Northern Ireland": "كتاب غير روائيين من أيرلندا الشمالية في القرن 20",
    "18th-century non-fiction writers from the Russian Empire": "كتاب غير روائيين من الإمبراطورية الروسية في القرن 18",
    "19th-century poets from Ottoman Arabia": "شعراء من الدولة العثمانية في شبه الجزيرة العربية في القرن 19",
}

test_data_2 = {
    "11th-century historians from the Abbasid Caliphate": "مؤرخون من الدولة العباسية في القرن 11",
    "10th-century historians from the Fatimid Caliphate": "مؤرخون من الدولة الفاطمية في القرن 10",
    "15th-century historians from the Ottoman Empire": "مؤرخون من الدولة العثمانية في القرن 15",
    "16th-century historians from the Ottoman Empire": "مؤرخون من الدولة العثمانية في القرن 16",
    "17th-century historians from the Ottoman Empire": "مؤرخون من الدولة العثمانية في القرن 17",
    "18th-century historians from the Ottoman Empire": "مؤرخون من الدولة العثمانية في القرن 18",
    "19th-century historians from the Ottoman Empire": "مؤرخون من الدولة العثمانية في القرن 19",
    "18th-century historians from the Russian Empire": "مؤرخون من الإمبراطورية الروسية في القرن 18",
    "19th-century historians from the Russian Empire": "مؤرخون من الإمبراطورية الروسية في القرن 19",
    "19th-century illustrators from the Russian Empire": "رسامون توضيحيون من الإمبراطورية الروسية في القرن 19",
    "10th-century Jews from al-Andalus": "يهود من الأندلس في القرن 10",
    "11th-century Jews from al-Andalus": "يهود من الأندلس في القرن 11",
    "12th-century Jews from al-Andalus": "يهود من الأندلس في القرن 12",
    "9th-century Jews from al-Andalus": "يهود من الأندلس في القرن 9",
    "16th-century Jews from the Ottoman Empire": "يهود من الدولة العثمانية في القرن 16",
    "17th-century Jews from the Ottoman Empire": "يهود من الدولة العثمانية في القرن 17",
    "19th-century Jews from the Russian Empire": "يهود من الإمبراطورية الروسية في القرن 19",
    "19th-century journalists from the Ottoman Empire": "صحفيون من الدولة العثمانية في القرن 19",
    "20th-century journalists from the Ottoman Empire": "صحفيون من الدولة العثمانية في القرن 20",
    "19th-century journalists from the Russian Empire": "صحفيون من الإمبراطورية الروسية في القرن 19",
    "20th-century LGBTQ people from Northern Ireland": "أعلام إل جي بي تي كيو من أيرلندا الشمالية في القرن 20",
    "21st-century LGBTQ people from Northern Ireland": "أعلام إل جي بي تي كيو من أيرلندا الشمالية في القرن 21",
    "19th-century LGBTQ people from the Russian Empire": "أعلام إل جي بي تي كيو من الإمبراطورية الروسية في القرن 19",
    "20th-century male actors from Georgia (country)": "ممثلون ذكور من جورجيا في القرن 20",
    "21st-century male actors from Georgia (country)": "ممثلون ذكور من جورجيا في القرن 21",
    "20th-century male actors from Northern Ireland": "ممثلون ذكور من أيرلندا الشمالية في القرن 20",
    "21st-century male actors from Northern Ireland": "ممثلون ذكور من أيرلندا الشمالية في القرن 21",
    "19th-century male actors from the Russian Empire": "ممثلون ذكور من الإمبراطورية الروسية في القرن 19",
    "19th-century male artists from the Russian Empire": "فنانون ذكور من الإمبراطورية الروسية في القرن 19",
    "19th-century male writers from the Russian Empire": "كتاب ذكور من الإمبراطورية الروسية في القرن 19",
    "18th-century mathematicians from the Russian Empire": "رياضياتيون من الإمبراطورية الروسية في القرن 18",
    "19th-century mathematicians from the Russian Empire": "رياضياتيون من الإمبراطورية الروسية في القرن 19",
    "18th-century military personnel from the Russian Empire": "أفراد عسكريون من الإمبراطورية الروسية في القرن 18",
    "19th-century military personnel from the Russian Empire": "أفراد عسكريون من الإمبراطورية الروسية في القرن 19",
    "18th-century musicians from Bohemia": "موسيقيون من بوهيميا في القرن 18",
    "21st-century musicians from Georgia (country)": "موسيقيون من جورجيا في القرن 21",
    "19th-century musicians from the Russian Empire": "موسيقيون من الإمبراطورية الروسية في القرن 19",
    "18th-century musicians from the Russian Empire": "موسيقيون من الإمبراطورية الروسية في القرن 18",
    "10th-century nobility from the Kingdom of León": "نبلاء من مملكة ليون في القرن 10",
    "11th-century nobility from the Kingdom of León": "نبلاء من مملكة ليون في القرن 11",
    "12th-century nobility from the Kingdom of Navarre": "نبلاء من مملكة نبرة في القرن 12",
    "13th-century nobility from the Kingdom of Navarre": "نبلاء من مملكة نبرة في القرن 13",
    "14th-century nobility from the Kingdom of Navarre": "نبلاء من مملكة نبرة في القرن 14",
    "15th-century nobility from the Kingdom of Navarre": "نبلاء من مملكة نبرة في القرن 15",
    "19th-century non-fiction writers from the Russian Empire": "كتاب غير روائيين من الإمبراطورية الروسية في القرن 19",
    "18th-century novelists from the Russian Empire": "روائيون من الإمبراطورية الروسية في القرن 18",
    "19th-century novelists from the Russian Empire": "روائيون من الإمبراطورية الروسية في القرن 19",
    "18th-century painters from Bohemia": "رسامون من بوهيميا في القرن 18",
    "20th-century painters from Georgia (country)": "رسامون من جورجيا في القرن 20",
    "19th-century painters from the Ottoman Empire": "رسامون من الدولة العثمانية في القرن 19",
    "20th-century painters from the Ottoman Empire": "رسامون من الدولة العثمانية في القرن 20",
    "18th-century painters from the Russian Empire": "رسامون من الإمبراطورية الروسية في القرن 18",
    "19th-century painters from the Russian Empire": "رسامون من الإمبراطورية الروسية في القرن 19",
    "10th-century people from al-Andalus": "أشخاص من الأندلس في القرن 10",
    "11th-century people from al-Andalus": "أشخاص من الأندلس في القرن 11",
    "12th-century people from al-Andalus": "أشخاص من الأندلس في القرن 12",
    "13th-century people from al-Andalus": "أشخاص من الأندلس في القرن 13",
    "14th-century people from al-Andalus": "أشخاص من الأندلس في القرن 14",
    "15th-century people from al-Andalus": "أشخاص من الأندلس في القرن 15",
    "8th-century people from al-Andalus": "أشخاص من الأندلس في القرن 8",
    "9th-century people from al-Andalus": "أشخاص من الأندلس في القرن 9",
    "13th-century people from bohemia": "أشخاص من بوهيميا في القرن 13",
    "14th-century people from Bohemia": "أشخاص من بوهيميا في القرن 14",
    "15th-century people from Bohemia": "أشخاص من بوهيميا في القرن 15",
    "16th-century people from Bohemia": "أشخاص من بوهيميا في القرن 16",
    "17th-century people from Bohemia": "أشخاص من بوهيميا في القرن 17",
    "18th-century people from Bohemia": "أشخاص من بوهيميا في القرن 18",
    "14th-century people from Georgia (country)": "أشخاص من جورجيا في القرن 14",
    "16th-century people from Georgia (country)": "أشخاص من جورجيا في القرن 16",
    "17th-century people from Georgia (country)": "أشخاص من جورجيا في القرن 17",
    "18th-century people from Georgia (country)": "أشخاص من جورجيا في القرن 18",
    "20th-century people from Georgia (country)": "أشخاص من جورجيا في القرن 20",
    "21st-century people from Nevada": "أشخاص من نيفادا في القرن 21",
    "21st-century people from New York (state)": "أشخاص من ولاية نيويورك في القرن 21",
    "19th-century people from North Dakota": "أشخاص من داكوتا الشمالية في القرن 19",
    "21st-century people from North Dakota": "أشخاص من داكوتا الشمالية في القرن 21",
    "19th-century people from Ottoman Iraq": "أشخاص من العراق العثماني في القرن 19",
    "13th-century people from the Abbasid Caliphate": "أشخاص من الدولة العباسية في القرن 13",
    "11th-century people from the Abbasid Caliphate": "أشخاص من الدولة العباسية في القرن 11",
    "12th-century people from the Abbasid Caliphate": "أشخاص من الدولة العباسية في القرن 12",
    "10th-century people from the County of Barcelona": "أشخاص من كونتية برشلونة في القرن 10",
    "11th-century people from the County of Barcelona": "أشخاص من كونتية برشلونة في القرن 11",
    "12th-century people from the County of Barcelona": "أشخاص من كونتية برشلونة في القرن 12",
    "9th-century people from the County of Barcelona": "أشخاص من كونتية برشلونة في القرن 9",
    "10th-century people from the Fatimid Caliphate": "أشخاص من الدولة الفاطمية في القرن 10",
    "11th-century people from the Fatimid Caliphate": "أشخاص من الدولة الفاطمية في القرن 11",
    "12th-century people from the Fatimid Caliphate": "أشخاص من الدولة الفاطمية في القرن 12",
    "11th-century people from the Kingdom of Jerusalem": "أشخاص من مملكة بيت المقدس في القرن 11",
    "12th-century people from the Kingdom of Jerusalem": "أشخاص من مملكة بيت المقدس في القرن 12",
    "13th-century people from the Kingdom of Jerusalem": "أشخاص من مملكة بيت المقدس في القرن 13",
    "10th-century people from the Kingdom of León": "أشخاص من مملكة ليون في القرن 10",
    "11th-century people from the Kingdom of León": "أشخاص من مملكة ليون في القرن 11",
    "13th-century people from the kingdom of león": "أشخاص من مملكة ليون في القرن 13",
    "12th-century people from the Kingdom of Navarre": "أشخاص من مملكة نبرة في القرن 12",
    "13th-century people from the Kingdom of Navarre": "أشخاص من مملكة نبرة في القرن 13",
    "14th-century people from the Kingdom of Navarre": "أشخاص من مملكة نبرة في القرن 14",
    "15th-century people from the Kingdom of Navarre": "أشخاص من مملكة نبرة في القرن 15",
    "16th-century people from the Kingdom of Navarre": "أشخاص من مملكة نبرة في القرن 16",
    "10th-century people from the Kingdom of Pamplona": "أشخاص من مملكة نبرة في القرن 10",
    "11th-century people from the Kingdom of Pamplona": "أشخاص من مملكة نبرة في القرن 11",
    "9th-century people from the Kingdom of Pamplona": "أشخاص من مملكة نبرة في القرن 9",
    "13th-century people from the Mamluk Sultanate": "أشخاص من مماليك مصر في القرن 13",
    "14th-century people from the Mamluk Sultanate": "أشخاص من مماليك مصر في القرن 14",
    "15th-century people from the Mamluk Sultanate": "أشخاص من مماليك مصر في القرن 15",
    "16th-century people from the Mamluk Sultanate": "أشخاص من مماليك مصر في القرن 16",
    "13th-century people from the Ottoman Empire": "أشخاص من الدولة العثمانية في القرن 13",
    "14th-century people from the Ottoman Empire": "أشخاص من الدولة العثمانية في القرن 14",
    "15th-century people from the Ottoman Empire": "أشخاص من الدولة العثمانية في القرن 15",
    "16th-century people from the Ottoman Empire": "أشخاص من الدولة العثمانية في القرن 16",
    "17th-century people from the Ottoman Empire": "أشخاص من الدولة العثمانية في القرن 17",
    "18th-century people from the Ottoman Empire": "أشخاص من الدولة العثمانية في القرن 18",
    "19th-century people from the Ottoman Empire": "أشخاص من الدولة العثمانية في القرن 19",
    "20th-century people from the Ottoman Empire": "أشخاص من الدولة العثمانية في القرن 20",
    "16th-century people from the Polish–Lithuanian Commonwealth": "أشخاص من الكومنولث البولندي الليتواني في القرن 16",
    "13th-century people from the Republic of Florence": "أشخاص من جمهورية فلورنسا في القرن 13",
    "14th-century people from the Republic of Florence": "أشخاص من جمهورية فلورنسا في القرن 14",
    "15th-century people from the Republic of Florence": "أشخاص من جمهورية فلورنسا في القرن 15",
    "16th-century people from the Republic of Florence": "أشخاص من جمهورية فلورنسا في القرن 16",
    "16th-century people from the Republic of Geneva": "أشخاص من جمهورية جنيف في القرن 16",
    "17th-century people from the Republic of Geneva": "أشخاص من جمهورية جنيف في القرن 17",
    "18th-century people from the Republic of Geneva": "أشخاص من جمهورية جنيف في القرن 18",
    "20th-century people from the Russian Empire": "أشخاص من الإمبراطورية الروسية في القرن 20",
    "8th-century people from the Umayyad Caliphate": "أشخاص من الدولة الأموية في القرن 8",
    "7th-century people from the Umayyad Caliphate": "أشخاص من الدولة الأموية في القرن 7",
    "6th-century people from the Visigothic Kingdom": "أشخاص من مملكة القوط في القرن 6",
    "7th-century people from the Visigothic Kingdom": "أشخاص من مملكة القوط في القرن 7",
    "19th-century people from West Virginia": "أشخاص من فرجينيا الغربية في القرن 19",
    "19th-century philosophers from the Russian Empire": "فلاسفة من الإمبراطورية الروسية في القرن 19",
    "19th-century photographers from the Russian Empire": "مصورون من الإمبراطورية الروسية في القرن 19",
    "17th-century physicians from Bohemia": "أطباء من بوهيميا في القرن 17",
    "15th-century physicians from the Ottoman Empire": "أطباء من الدولة العثمانية في القرن 15",
    "16th-century physicians from the Ottoman Empire": "أطباء من الدولة العثمانية في القرن 16",
    "18th-century physicians from the Ottoman Empire": "أطباء من الدولة العثمانية في القرن 18",
    "19th-century physicians from the Ottoman Empire": "أطباء من الدولة العثمانية في القرن 19",
    "20th-century physicians from the Ottoman Empire": "أطباء من الدولة العثمانية في القرن 20",
    "17th-century physicians from the Ottoman Empire": "أطباء من الدولة العثمانية في القرن 17",
    "18th-century physicians from the Russian Empire": "أطباء من الإمبراطورية الروسية في القرن 18",
    "19th-century physicians from the Russian Empire": "أطباء من الإمبراطورية الروسية في القرن 19",
    "19th-century pianists from the Russian Empire": "عازفو بيانو من الإمبراطورية الروسية في القرن 19",
    "19th-century poets from Georgia (country)": "شعراء من جورجيا في القرن 19",
    "14th-century poets from the Ottoman Empire": "شعراء من الدولة العثمانية في القرن 14",
    "15th-century poets from the Ottoman Empire": "شعراء من الدولة العثمانية في القرن 15",
    "16th-century poets from the Ottoman Empire": "شعراء من الدولة العثمانية في القرن 16",
    "17th-century poets from the Ottoman Empire": "شعراء من الدولة العثمانية في القرن 17",
    "18th-century poets from the Ottoman Empire": "شعراء من الدولة العثمانية في القرن 18",
    "19th-century poets from the Ottoman Empire": "شعراء من الدولة العثمانية في القرن 19",
    "20th-century poets from the Ottoman Empire": "شعراء من الدولة العثمانية في القرن 20",
    "18th-century poets from the Russian Empire": "شعراء من الإمبراطورية الروسية في القرن 18",
    "19th-century poets from the Russian Empire": "شعراء من الإمبراطورية الروسية في القرن 19",
    "21st-century politicians from Georgia (country)": "سياسيون من جورجيا في القرن 21",
    "18th-century politicians from the Russian Empire": "سياسيون من الإمبراطورية الروسية في القرن 18",
    "19th-century politicians from the Russian Empire": "سياسيون من الإمبراطورية الروسية في القرن 19",
    "10th-century princes from Kievan Rus'": "أمراء من كييف روس في القرن 10",
    "11th-century princes from Kievan Rus'": "أمراء من كييف روس في القرن 11",
    "12th-century princes from Kievan Rus'": "أمراء من كييف روس في القرن 12",
    "13th-century princes from Kievan Rus'": "أمراء من كييف روس في القرن 13",
    "15th-century rabbis from the Ottoman Empire": "حاخامات من الدولة العثمانية في القرن 15",
    "16th-century rabbis from the Ottoman Empire": "حاخامات من الدولة العثمانية في القرن 16",
    "17th-century rabbis from the Ottoman Empire": "حاخامات من الدولة العثمانية في القرن 17",
    "18th-century rabbis from the Ottoman Empire": "حاخامات من الدولة العثمانية في القرن 18",
    "19th-century rabbis from the Ottoman Empire": "حاخامات من الدولة العثمانية في القرن 19",
    "19th-century rabbis from the Russian Empire": "حاخامات من الإمبراطورية الروسية في القرن 19",
    "20th-century rabbis from the Russian Empire": "حاخامات من الإمبراطورية الروسية في القرن 20",
    "18th-century scholars from the Ottoman Empire": "دارسون من الدولة العثمانية في القرن 18",
    "19th-century scholars from the Ottoman Empire": "دارسون من الدولة العثمانية في القرن 19",
    "20th-century scholars from the Ottoman Empire": "دارسون من الدولة العثمانية في القرن 20",
    "16th-century scientists from the Ottoman Empire": "علماء من الدولة العثمانية في القرن 16",
    "17th-century scientists from the Ottoman Empire": "علماء من الدولة العثمانية في القرن 17",
    "18th-century scientists from the Ottoman Empire": "علماء من الدولة العثمانية في القرن 18",
    "19th-century scientists from the Ottoman Empire": "علماء من الدولة العثمانية في القرن 19",
    "20th-century scientists from the Ottoman Empire": "علماء من الدولة العثمانية في القرن 20",
    "18th-century scientists from the Russian Empire": "علماء من الإمبراطورية الروسية في القرن 18",
    "19th-century scientists from the Russian Empire": "علماء من الإمبراطورية الروسية في القرن 19",
    "18th-century sculptors from the Russian Empire": "نحاتون من الإمبراطورية الروسية في القرن 18",
    "19th-century sculptors from the Russian Empire": "نحاتون من الإمبراطورية الروسية في القرن 19",
    "19th-century short story writers from the Russian Empire": "كتاب قصة قصيرة من الإمبراطورية الروسية في القرن 19",
    "21st-century singers from Georgia (country)": "مغنون من جورجيا في القرن 21",
    "18th-century singers from the Russian Empire": "مغنون من الإمبراطورية الروسية في القرن 18",
    "18th-century translators from the Russian Empire": "مترجمون من الإمبراطورية الروسية في القرن 18",
    "19th-century translators from the Russian Empire": "مترجمون من الإمبراطورية الروسية في القرن 19",
    "19th-century women artists from the Russian Empire": "فنانات من الإمبراطورية الروسية في القرن 19",
    "21st-century women musicians from Northern Ireland": "موسيقيات من أيرلندا الشمالية في القرن 21",
    "19th-century women scientists from the Russian Empire": "عالمات من الإمبراطورية الروسية في القرن 19",
    "21st-century women singers from Northern Ireland": "مغنيات من أيرلندا الشمالية في القرن 21",
    "15th-century women writers from the Ottoman Empire": "كاتبات من الدولة العثمانية في القرن 15",
    "16th-century women writers from the Ottoman Empire": "كاتبات من الدولة العثمانية في القرن 16",
    "18th-century women writers from the Ottoman Empire": "كاتبات من الدولة العثمانية في القرن 18",
    "20th-century women writers from the Ottoman Empire": "كاتبات من الدولة العثمانية في القرن 20",
    "19th-century women writers from the Ottoman Empire": "كاتبات من الدولة العثمانية في القرن 19",
    "19th-century women writers from the Russian Empire": "كاتبات من الإمبراطورية الروسية في القرن 19",
    "10th-century writers from al-Andalus": "كتاب من الأندلس في القرن 10",
    "11th-century writers from al-Andalus": "كتاب من الأندلس في القرن 11",
    "12th-century writers from al-Andalus": "كتاب من الأندلس في القرن 12",
    "13th-century writers from al-Andalus": "كتاب من الأندلس في القرن 13",
    "14th-century writers from Bohemia": "كتاب من بوهيميا في القرن 14",
    "15th-century writers from Bohemia": "كتاب من بوهيميا في القرن 15",
    "16th-century writers from Bohemia": "كتاب من بوهيميا في القرن 16",
    "17th-century writers from Bohemia": "كتاب من بوهيميا في القرن 17",
    "18th-century writers from Bohemia": "كتاب من بوهيميا في القرن 18",
    "13th-century writers from Georgia (country)": "كتاب من جورجيا في القرن 13",
    "19th-century writers from Ottoman Iraq": "كتاب من العراق العثماني في القرن 19",
    "18th-century writers from the Ottoman Empire": "كتاب من الدولة العثمانية في القرن 18",
    "20th-century writers from the Ottoman Empire": "كتاب من الدولة العثمانية في القرن 20",
    "15th-century writers from the Ottoman Empire": "كتاب من الدولة العثمانية في القرن 15",
    "16th-century writers from the Ottoman Empire": "كتاب من الدولة العثمانية في القرن 16",
    "17th-century writers from the Ottoman Empire": "كتاب من الدولة العثمانية في القرن 17",
    "19th-century writers from the Ottoman Empire": "كتاب من الدولة العثمانية في القرن 19",
    "14th-century writers from the Ottoman Empire": "كتاب من الدولة العثمانية في القرن 14",
    "18th-century writers from the Republic of Geneva": "كتاب من جمهورية جنيف في القرن 18",
    "19th-century zoologists from the Russian Empire": "علماء حيوانات من الإمبراطورية الروسية في القرن 19",
}


@pytest.mark.parametrize("category,expected", test_data_1.items(), ids=test_data_1.keys())
@pytest.mark.fast
def test_resolve_v3i_extended_1(category: str, expected: str) -> None:
    """
    Test
    """
    result = resolve_year_job_from_countries(category)
    assert result == expected


@pytest.mark.parametrize("category,expected", test_data_2.items(), ids=test_data_2.keys())
@pytest.mark.fast
def test_resolve_v3i_extended_2(category: str, expected: str) -> None:
    """
    Test
    """
    result = resolve_year_job_from_countries(category)
    assert result == expected


to_test = [
    # ("test_resolve_v3i_extended_0", test_0),
    ("test_resolve_v3i_extended_1", test_data_1),
    ("test_resolve_v3i_extended_2", test_data_2),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_year_job_from_countries)

    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)

    # dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



import pytest

from ArWikiCats.new_resolvers.relations_resolver import new_relations_resolvers

# ======================
# Basic tests
# ======================


def test_unsupported_relation_type() -> None:
    """اختبار نوع علاقة غير مدعومة"""
    result = new_relations_resolvers("mars–venus space relations")
    assert result == ""


def test_empty_input() -> None:
    """اختبار إدخال فارغ"""
    result = new_relations_resolvers("")
    assert result == ""


def test_numeric_country_codes() -> None:
    """اختبار أكواد دول رقمية (غير مدعومة)"""
    result = new_relations_resolvers("123–456 relations")
    assert result == ""


# ======================
# اختبارات العلاقات النسائية
# ======================


def test_female_relations_basic() -> None:
    """Basic female relations with countries in dictionary"""

    result = new_relations_resolvers("canada–burma military relations")
    assert result == "العلاقات البورمية الكندية العسكرية"


def test_female_relations_special_nato() -> None:
    """Special NATO case with known country"""

    result = new_relations_resolvers("nato–canada relations")
    assert result == "علاقات الناتو وكندا"


def test_female_relations_unknown_country() -> None:
    """Unknown country should return empty string"""

    result = new_relations_resolvers("unknown–canada relations")
    assert result == ""


# ======================
# اختبارات العلاقات الذكورية
# ======================


def test_male_relations_basic() -> None:
    """Basic male relations"""

    result = new_relations_resolvers("german–polish football rivalry")
    assert result == "التنافس الألماني البولندي في كرة القدم"


def test_male_relations_with_en_dash() -> None:
    """Use en-dash instead of hyphen"""
    result = new_relations_resolvers("afghan–prussian conflict")
    assert result == "الصراع الأفغاني البروسي"


# ======================
# اختبارات البادئات (P17_PREFIXES)
# ======================


def test_p17_prefixes_basic() -> None:
    """Basic P17 prefix handling"""

    result = new_relations_resolvers("afghanistan–pakistan proxy conflict")
    assert result == "صراع أفغانستان وباكستان بالوكالة"


def test_p17_prefixes_unknown_country() -> None:
    """Unknown country in P17 context"""

    result = new_relations_resolvers("unknown–pakistan conflict")
    assert result == ""


# ======================
# حالات خاصة
# ======================


def test_special_nato_case_male() -> None:
    """Male NATO relation handling"""

    result = new_relations_resolvers("nato–germany conflict")
    assert result == "صراع ألمانيا والناتو"


def test_missing_separator() -> None:
    """Missing separator should fail"""
    result = new_relations_resolvers("canadaburma relations")
    assert result == ""


# ======================
# Edge cases
# ======================


def test_trailing_whitespace() -> None:
    """Trailing whitespace"""

    result = new_relations_resolvers("canada–burma relations   ")
    assert result == "العلاقات البورمية الكندية"


def test_leading_whitespace() -> None:
    """Leading whitespace"""

    result = new_relations_resolvers("   canada–burma relations")
    assert result == "العلاقات البورمية الكندية"


def test_mixed_case_input() -> None:
    """Mixed-case input"""

    result = new_relations_resolvers("CaNaDa–BuRmA ReLaTiOnS")
    assert result == "العلاقات البورمية الكندية"


def test_multiple_dashes() -> None:
    """Multiple separators should fail"""

    result = new_relations_resolvers("canada–burma–india relations")
    assert result == ""



"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.nationalities_resolvers.nationalities_v2 import resolve_by_nats

test_data_males = {
    "christian religious orders": "أخويات دينية مسيحية",
    "christian political parties": "أحزاب سياسية مسيحية",
    "jewish political parties": "أحزاب سياسية يهودية",
    "palestinian political parties": "أحزاب سياسية فلسطينية",
    "Yemeni expatriates": "يمنيون مغتربون",
    "Yemeni emigrants": "يمنيون مهاجرون",
}

test_data_ar = {}


@pytest.mark.parametrize("category, expected", test_data_males.items(), ids=test_data_males.keys())
@pytest.mark.fast
def test_resolve_males(category: str, expected: str) -> None:
    label = resolve_by_nats(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data_ar.items(), ids=test_data_ar.keys())
@pytest.mark.fast
def test_resolve_ar(category: str, expected: str) -> None:
    label = resolve_by_nats(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_resolve_males", test_data_males, resolve_by_nats),
    ("test_resolve_ar", test_data_ar, resolve_by_nats),
]


@pytest.mark.dump
@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""
!
"""

import functools
import inspect
import json
from pathlib import Path

import jsonlines

SAVE_ENABLE = True
SAVE_ENABLE = False


def save(path: Path | str, data: dict | list) -> str:
    """Append data to the specified JSONL file, creating it if needed."""
    path = Path(path)
    if isinstance(data, dict):
        data = [data]
    if not path.exists():
        path.parent.mkdir(parents=True, exist_ok=True)
        with jsonlines.open(path, mode="w") as writer:
            writer.write({})
    with jsonlines.open(path, mode="a") as writer:
        writer.write(data)


already_saved = {}


def dump_data(enable: bool = False, input_keys: list = None, compare_with_output: str = ""):
    """
    Decorator to save function inputs and output into a JSONL file.

    If input_keys is empty or None, all inputs (args + kwargs) are saved.
    Only saves unique data entries (no duplicates).
    """

    def decorator(func: callable) -> callable:
        """Wrap a function so its inputs and outputs are written to JSONL."""

        @functools.wraps(func)
        def wrapper(*args, **kwargs):
            """Execute the wrapped function and persist call details when enabled."""
            # Execute the wrapped function
            output = func(*args, **kwargs)

            if not SAVE_ENABLE and not enable:
                return output

            if not output:
                return output

            if isinstance(output, (list, tuple)) and not any(output):
                return output

            path = Path(__file__).parent / f"{func.__name__}.jsonl"

            bound_args = inspect.signature(func).bind(*args, **kwargs)
            bound_args.apply_defaults()
            all_arguments = bound_args.arguments
            data = {}
            # Case 1: Save all inputs
            if not input_keys:
                data.update(all_arguments)
            # Case 2: Save only the selected keys
            else:
                for key in input_keys:
                    if key in all_arguments:
                        data[key] = all_arguments[key]

            # Add function output
            data["output"] = output

            if compare_with_output and data.get(compare_with_output) == output:
                return output

            # Create a unique key for this data entry to prevent duplicates
            # Use frozenset for hashable representation of the data
            try:
                data_key = (func.__name__, json.dumps(data, sort_keys=True))
            except TypeError:
                # If data is not serializable, use string representation
                data_key = (func.__name__, str(data))

            # Check if this exact data has already been saved
            if data_key in already_saved:
                return output

            # Mark as saved
            already_saved[data_key] = True

            # Write the JSON line using jsonlines
            with jsonlines.open(path, mode="a") as writer:
                writer.write(data)

            return output

        return wrapper

    return decorator



#!/usr/bin/python3
"""Integration tests """

import re

import pytest

from ArWikiCats.translations_formats import FormatData


@pytest.fixture
def sample_data() -> tuple[dict[str, str], dict[str, str]]:
    formatted_data = {
        "men's {sport} world cup": "كأس العالم للرجال في {sport_label}",
        "women's {sport} championship": "بطولة السيدات في {sport_label}",
        "{sport} records": "سجلات {sport_label}",
        "{sport} league": "دوري {sport_label}",
    }

    data_list = {
        "football": "كرة القدم",
        "basketball": "كرة السلة",
        "snooker": "سنوكر",
        "rugby league": "دوري الرجبي",
        "rugby": "الرجبي",
    }

    return formatted_data, data_list


@pytest.mark.unit
def test_keys_to_pattern(sample_data: tuple[dict[str, str], dict[str, str]]) -> None:
    formatted_data, data_list = sample_data
    bot = FormatData(formatted_data, data_list, "{sport}", "{sport_label}")
    pattern = bot.keys_to_pattern()
    assert isinstance(pattern, re.Pattern)
    assert pattern.search("football") is not None
    assert pattern.search("snooker") is not None


@pytest.mark.unit
@pytest.mark.parametrize(
    "category,expected",
    [
        ("men's football world cup", "football"),
        ("women's basketball championship", "basketball"),
        ("women's rugby league championship", "rugby league"),
        ("random text", ""),
    ],
)
def test_match_key(category: str, expected: str, sample_data: tuple[dict[str, str], dict[str, str]]) -> None:
    formatted_data, data_list = sample_data
    bot = FormatData(formatted_data, data_list, "{sport}", "{sport_label}")
    assert bot.match_key(category) == expected


@pytest.mark.unit
@pytest.mark.parametrize(
    "template_label,sport_label,expected",
    [
        ("كأس العالم في xoxo", "كرة القدم", "كأس العالم في كرة القدم"),
        ("xoxo بطولة", "كرة السلة", "كرة السلة بطولة"),
        ("", "كرة الطائرة", ""),  # placeholder not found
    ],
    ids=[k for k in range(3)],
)
def test_apply_pattern_replacement(
    template_label: str, sport_label: str, expected: str, sample_data: tuple[dict[str, str], dict[str, str]]
) -> None:
    formatted_data, data_list = sample_data
    bot = FormatData(formatted_data, data_list, value_placeholder="xoxo")
    assert bot.apply_pattern_replacement(template_label, sport_label) == expected


@pytest.mark.unit
@pytest.mark.parametrize(
    "category,sport_key,expected",
    [
        ("men's football world cup", "football", "men's xoxo world cup"),
        ("women's basketball championship", "basketball", "women's xoxo championship"),
    ],
)
def test_normalize_category(
    category: str, sport_key: str, expected: str, sample_data: tuple[dict[str, str], dict[str, str]]
) -> None:
    formatted_data, data_list = sample_data
    bot = FormatData(formatted_data, data_list)
    result = bot.normalize_category(category, sport_key)
    assert result.lower() == expected.lower()


@pytest.mark.unit
@pytest.mark.parametrize(
    "category,expected",
    [
        ("men's football world cup", "كأس العالم للرجال في كرة القدم"),
        ("women's basketball championship", "بطولة السيدات في كرة السلة"),
        ("women's Rugby championship", "بطولة السيدات في الرجبي"),
        ("women's Rugby League championship", "بطولة السيدات في دوري الرجبي"),
        ("snooker records", "سجلات سنوكر"),
        ("unknown category", ""),
    ],
    ids=[k for k in range(6)],
)
def test_search(sample_data: tuple[dict[str, str], dict[str, str]], category: str, expected: str) -> None:
    formatted_data, data_list = sample_data
    bot = FormatData(formatted_data, data_list, key_placeholder="{sport}", value_placeholder="{sport_label}")
    assert bot.search(category) == expected


@pytest.mark.unit
def test_search_no_sport_match(sample_data: tuple[dict[str, str], dict[str, str]]) -> None:
    formatted_data, data_list = sample_data
    bot = FormatData(formatted_data, data_list)
    assert bot.search("unrelated topic") == ""


@pytest.mark.unit
def test_search_no_template_label(sample_data: tuple[dict[str, str], dict[str, str]]) -> None:
    formatted_data, data_list = sample_data
    bot = FormatData(formatted_data, data_list)
    bot.formatted_data = {}  # remove templates
    assert bot.search("men's football world cup") == ""


@pytest.mark.unit
def test_case(sample_data: tuple[dict[str, str], dict[str, str]]) -> None:
    formatted_data, data_list = sample_data
    bot = FormatData(formatted_data, data_list, key_placeholder="{sport}", value_placeholder="{sport_label}")
    result = bot.search("men's football world cup")
    assert result == "كأس العالم للرجال في كرة القدم"


@pytest.mark.unit
def test_get_template(sample_data: tuple[dict[str, str], dict[str, str]]) -> None:
    formatted_data, data_list = sample_data
    bot = FormatData(formatted_data, data_list, key_placeholder="{sport}", value_placeholder="{sport_label}")
    normalized = bot.normalize_category("men's football world cup", "football")
    assert normalized == "men's {sport} world cup"
    template_label = bot.get_template("football", "men's football world cup")
    assert template_label == "كأس العالم للرجال في {sport_label}"


@pytest.mark.unit
def test_empty_data_lists() -> None:
    bot = FormatData({}, {}, key_placeholder="{k}", value_placeholder="{v}")
    assert bot.match_key("any") == ""
    assert bot.search("text") == ""
    assert bot.keys_to_pattern() is None


@pytest.mark.unit
def test_case_insensitivity(sample_data: tuple[dict[str, str], dict[str, str]]) -> None:
    formatted_data, data_list = sample_data
    bot = FormatData(formatted_data, data_list, key_placeholder="{sport}", value_placeholder="{sport_label}")
    result = bot.search("MEN'S FOOTBALL WORLD CUP")
    assert result == "كأس العالم للرجال في كرة القدم"



#!/usr/bin/python3
"""Integration tests for format_multi_data  """

import pytest

from ArWikiCats.translations_formats import (
    MultiDataFormatterBase,
    format_multi_data,
)


@pytest.fixture
def multi_bot() -> MultiDataFormatterBase:
    under_data = {
        "shooting location": "موقع التصوير",
        "developer": "التطوير",
        "location": "الموقع",
        "setting": "الأحداث",
        "disestablishment": "الانحلال",
        "reestablishment": "إعادة التأسيس",
        "establishment": "التأسيس",
        "setting location": "موقع الأحداث",
        "invention": "الاختراع",
        "country": "البلد",
        "introduction": "الاستحداث",
        "formal description": "الوصف",
        "photographing": "التصوير",
        "completion": "الانتهاء",
        "opening": "الافتتاح",
    }

    formatted_data = {
        "by year - {en}": "حسب {ar}",
        "by {en}": "حسب {ar}",
        "by {en2}": "حسب {ar2}",
        "by {en} or {en2}": "حسب {ar} أو {ar2}",
        "by {en} and {en2}": "حسب {ar} و{ar2}",
        "by {en} by {en2}": "حسب {ar} حسب {ar2}",
        "by city of {en}": "حسب مدينة {ar}",
        "by date of {en}": "حسب تاريخ {ar}",
        "by country of {en}": "حسب بلد {ar}",
        "by continent of {en}": "حسب قارة {ar}",
        "by location of {en}": "حسب موقع {ar}",
        "by period of {en}": "حسب حقبة {ar}",
        "by time of {en}": "حسب وقت {ar}",
        "by year of {en}": "حسب سنة {ar}",
        "by decade of {en}": "حسب عقد {ar}",
        "by era of {en}": "حسب عصر {ar}",
        "by millennium of {en}": "حسب ألفية {ar}",
        "by century of {en}": "حسب قرن {ar}",
        "by {en} and city of {en2}": "حسب {ar} ومدينة {ar2}",
    }

    return format_multi_data(
        formatted_data=formatted_data,
        data_list=under_data,
        key_placeholder="{en}",
        value_placeholder="{ar}",
        data_list2=under_data,
        key2_placeholder="{en2}",
        value2_placeholder="{ar2}",
        search_first_part=True,
        use_other_formatted_data=True,
    )


# =========================================================
#           data_compare
# =========================================================

data_compare = {
    "by country and country": "حسب البلد والبلد",
    "by shooting location": "حسب موقع التصوير",
    "by date of developer": "حسب تاريخ التطوير",
    "by city of disestablishment": "حسب مدينة الانحلال",
    "by city of reestablishment": "حسب مدينة إعادة التأسيس",
    "by city of establishment": "حسب مدينة التأسيس",
    "by country and city of setting": "حسب البلد ومدينة الأحداث",
    "by country and city of developer": "حسب البلد ومدينة التطوير",
}


@pytest.mark.parametrize("category, expected", data_compare.items(), ids=data_compare.keys())
@pytest.mark.fast
def test_data_compare_multi(multi_bot: MultiDataFormatterBase, category: str, expected: str) -> None:
    label2 = multi_bot.search_all(category)

    assert label2 == expected



"""
Tests for army2 resolver - comprehensive coverage of all patterns and countries
"""

import pytest

from ArWikiCats.new_resolvers.nationalities_resolvers.ministers_resolver import resolve_secretaries_labels

fast_data = {
    # US specific pattern
    "United States secretaries of state": "وزراء خارجية أمريكيون",  # Secretaries of state patterns - all countries from _all_country_with_nat
    "secretaries of state of eastern asia": "وزراء خارجية آسيويون شرقيون",
    "secretaries of state of eastern europe": "وزراء خارجية أوروبيون شرقيون",
    "secretaries of state of ecuador": "وزراء خارجية إكوادوريون",
    "secretaries of state of egypt": "وزراء خارجية مصريون",
    "secretaries of state of united arab emirates": "وزراء خارجية إماراتيون",
    "secretaries of state of england": "وزراء خارجية إنجليز",
    "secretaries of state of equatorial guinea": "وزراء خارجية غينيون استوائيون",
    "secretaries of state for egypt": "وزراء خارجية مصريون",
    "secretaries of state for united arab emirates": "وزراء خارجية إماراتيون",
    "secretaries of state for england": "وزراء خارجية إنجليز",
    "secretaries of state for ecuador": "وزراء خارجية إكوادوريون",  # Assistant secretaries patterns - multiple countries
    "assistant secretaries of defense of egypt": "مساعدو وزير الدفاع المصري",
    "assistant secretaries of interior of united arab emirates": "مساعدو وزير الداخلية الإماراتي",
    "assistant secretaries of health of england": "مساعدو وزير الصحة الإنجليزي",
    "assistant secretaries of education of ecuador": "مساعدو وزير التعليم الإكوادوري",
    "assistant secretaries of finance of eastern asia": "مساعدو وزير المالية الآسيوي الشرقي",
    "assistant secretaries of defense of eastern europe": "مساعدو وزير الدفاع الأوروبي الشرقي",
    "assistant secretaries of agriculture of equatorial guinea": "مساعدو وزير الزراعة الغيني الاستوائي",
    # Deputy secretaries patterns - multiple countries
    "deputy secretaries of defense of egypt": "نواب وزير الدفاع المصري",
    "deputy secretaries of interior of united arab emirates": "نواب وزير الداخلية الإماراتي",
    "deputy secretaries of health of england": "نواب وزير الصحة الإنجليزي",
    "deputy secretaries of finance of ecuador": "نواب وزير المالية الإكوادوري",
    "deputy secretaries of economy of eastern asia": "نواب وزير الاقتصاد الآسيوي الشرقي",
    "deputy secretaries of culture of eastern europe": "نواب وزير الثقافة الأوروبي الشرقي",
    # Under secretaries patterns - multiple countries
    "under secretaries of defense of egypt": "نواب وزير الدفاع المصري للشؤون المتخصصة",
    "under secretaries of interior of united arab emirates": "نواب وزير الداخلية الإماراتي للشؤون المتخصصة",
    "under secretaries of education of england": "نواب وزير التعليم الإنجليزي للشؤون المتخصصة",
    "under secretaries of agriculture of ecuador": "نواب وزير الزراعة الإكوادوري للشؤون المتخصصة",
    "under secretaries of transport of eastern asia": "نواب وزير النقل الآسيوي الشرقي للشؤون المتخصصة",
    # Country secretaries of ministry patterns - Egyptian
    "secretaries of defense of egypt": "وزراء دفاع مصريون",
    "secretaries of interior of egypt": "وزراء داخلية مصريون",
    "secretaries of health of egypt": "وزراء صحة مصريون",
    "secretaries of education of egypt": "وزراء تعليم مصريون",
    "secretaries of agriculture of egypt": "وزراء زراعة مصريون",
    "secretaries of finance of egypt": "وزراء مالية مصريون",
    "secretaries of culture of egypt": "وزراء ثقافة مصريون",
    "secretaries of tourism of egypt": "وزراء سياحة مصريون",
    # Country secretaries of ministry patterns - Emirati
    "secretaries of defense of united arab emirates": "وزراء دفاع إماراتيون",
    "secretaries of interior of united arab emirates": "وزراء داخلية إماراتيون",
    "secretaries of foreign affairs of united arab emirates": "وزراء شؤون خارجية إماراتيون",
    "secretaries of energy of united arab emirates": "وزراء طاقة إماراتيون",
    "secretaries of economy of united arab emirates": "وزراء اقتصاد إماراتيون",
    # Country secretaries of ministry patterns - English
    "secretaries of defense of england": "وزراء دفاع إنجليز",
    "secretaries of health of england": "وزراء صحة إنجليز",
    "secretaries of education of england": "وزراء تعليم إنجليز",
    "secretaries of foreign affairs of england": "وزراء شؤون خارجية إنجليز",
    "secretaries of justice of england": "وزراء عدل إنجليز",
    # Country secretaries of ministry patterns - Ecuadorian
    "secretaries of agriculture of ecuador": "وزراء زراعة إكوادوريون",
    "secretaries of finance of ecuador": "وزراء مالية إكوادوريون",
    "secretaries of defense of ecuador": "وزراء دفاع إكوادوريون",
    "secretaries of environment of ecuador": "وزراء بيئة إكوادوريون",  # Country secretaries of ministry patterns - Eastern Asian
    "secretaries of finance of eastern asia": "وزراء مالية آسيويون شرقيون",
    "secretaries of defense of eastern asia": "وزراء دفاع آسيويون شرقيون",
    "secretaries of economy of eastern asia": "وزراء اقتصاد آسيويون شرقيون",
    # Country secretaries of ministry patterns - Eastern European
    "secretaries of defense of eastern europe": "وزراء دفاع أوروبيون شرقيون",
    "secretaries of interior of eastern europe": "وزراء داخلية أوروبيون شرقيون",
    "secretaries of culture of eastern europe": "وزراء ثقافة أوروبيون شرقيون",
    # Country secretaries of ministry patterns - Equatorial Guinean
    "secretaries of defense of equatorial guinea": "وزراء دفاع غينيون استوائيون",
    "secretaries of agriculture of equatorial guinea": "وزراء زراعة غينيون استوائيون",
    "secretaries of health of equatorial guinea": "وزراء صحة غينيون استوائيون",
    # Secretaries of ministry (no country) - all ministries
    "secretaries of defense": "وزراء دفاع",
    "secretaries of interior": "وزراء داخلية",
    "secretaries of health": "وزراء صحة",
    "secretaries of education": "وزراء تعليم",
    "secretaries of agriculture": "وزراء زراعة",
    "secretaries of navy": "وزراء بحرية",
    "secretaries of veterans affairs": "وزراء شؤون محاربين قدامى",
    "secretaries of veterans and military families": "وزراء شؤون محاربين قدامى",
    "secretaries of military affairs": "وزراء شؤون عسكرية",
    "secretaries of constitutional affairs": "وزراء شؤون دستورية",
    "secretaries of treasury": "وزراء خزانة",
    "secretaries of homeland security": "وزراء أمن داخلي",
    "secretaries of transportation": "وزراء نقل",
    "secretaries of energy": "وزراء طاقة",
    "secretaries of environment": "وزراء بيئة",
    "secretaries of finance": "وزراء مالية",
    "secretaries of commerce": "وزراء تجارة",
    "secretaries of trade": "وزراء تجارة",
    "secretaries of justice": "وزراء عدل",
    "secretaries of foreign affairs": "وزراء شؤون خارجية",
    "secretaries of foreign": "وزراء خارجية",
    "secretaries of culture": "وزراء ثقافة",
    "secretaries of economy": "وزراء اقتصاد",
    "secretaries of fisheries": "وزراء ثروة سمكية",
    "secretaries of human rights": "وزراء حقوق الإنسان",
    "secretaries of immigration": "وزراء هجرة",
    "secretaries of industry": "وزراء صناعة",
    "secretaries of information": "وزراء إعلام",
    "secretaries of infrastructure": "وزراء بنية تحتية",
    "secretaries of intelligence": "وزراء مخابرات",
    "secretaries of labor": "وزراء عمل",
    "secretaries of labour": "وزراء عمل",
    "secretaries of mining": "وزراء تعدين",
    "secretaries of oil": "وزراء بترول",
    "secretaries of security": "وزراء أمن",
    "secretaries of nuclear security": "وزراء أمن نووي",
    "secretaries of sports": "وزراء رياضة",
    "secretaries of technology": "وزراء تقانة",
    "secretaries of tourism": "وزراء سياحة",
    "secretaries of water": "وزراء مياه",
    "secretaries of army": "وزراء جيش",
    "secretaries of war": "وزراء حرب",
    "secretaries of construction": "وزراء بناء",
    "secretaries of communication": "وزراء اتصالات",
    "secretaries of communications": "وزراء اتصالات",
    "secretaries of climate change": "وزراء تغير المناخ",
    "secretaries of national defence": "وزراء دفاع وطني",
    "secretaries of defence": "وزراء دفاع",
    "secretaries of family": "وزراء أسرة",
    "secretaries of internal affairs": "وزراء شؤون داخلية",
    "secretaries of indigenous affairs": "وزراء شؤون سكان أصليين",
    "secretaries of maritime affairs": "وزراء شؤون بحرية",
    "secretaries of social security": "وزراء ضمان اجتماعي",
    "secretaries of social affairs": "وزراء شؤون اجتماعية",
    "secretaries of gender equality": "وزراء المساواة بين الجنسين",
    "secretaries of colonial": "وزراء إستعمار",
    "secretaries of broadcasting": "وزراء إذاعة",
    "secretaries of land management": "وزراء إدارة أراضي",
    "secretaries of housing": "وزراء إسكان",
    "secretaries of housing and urban development": "وزراء إسكان وتنمية حضرية",
    "secretaries of public safety": "وزراء سلامة عامة",
    "secretaries of planning": "وزراء تخطيط",
    "secretaries of diaspora": "وزراء شتات",
    "secretaries of urban development": "وزراء تخطيط عمراني",
    "secretaries of law": "وزراء قانون",
    "secretaries of prisons": "وزراء سجون",
    "secretaries of public works": "وزراء أشغال عامة",
    "secretaries of research": "وزراء أبحاث",
    "secretaries of science": "وزراء العلم",
    "secretaries of civil service": "وزراء خدمة مدنية",
    "secretaries of irrigation": "وزراء ري",
    "secretaries of natural resources": "وزراء موارد طبيعية",
    "secretaries of religious affairs": "وزراء شؤون دينية",
    "secretaries of foreign trade": "وزراء تجارة خارجية",
    "secretaries of transport": "وزراء نقل",
    "secretaries of public service": "وزراء خدمة عامة",
    "secretaries of human services": "وزراء خدمات إنسانية",
    "secretaries of peace and reconciliation": "وزراء سلام ومصالحة",
    # State-level positions - multiple countries
    "state lieutenant governors of egypt": "نواب حكام الولايات في مصر",
    "state lieutenant governors of united arab emirates": "نواب حكام الولايات في الإمارات العربية المتحدة",
    "state lieutenant governors of ecuador": "نواب حكام الولايات في الإكوادور",
    "state lieutenant governors of england": "نواب حكام الولايات في إنجلترا",
    "state secretaries of state of egypt": "وزراء خارجية الولايات في مصر",
    "state secretaries of state of united arab emirates": "وزراء خارجية الولايات في الإمارات العربية المتحدة",
    "state secretaries of state of ecuador": "وزراء خارجية الولايات في الإكوادور",
    "state cabinet secretaries of egypt": "أعضاء مجلس وزراء مصر",
    "state cabinet secretaries of united arab emirates": "أعضاء مجلس وزراء الإمارات العربية المتحدة",
    "state cabinet secretaries of ecuador": "أعضاء مجلس وزراء الإكوادور",
    "state cabinet secretaries of england": "أعضاء مجلس وزراء إنجلترا",  # Hyphenated patterns - multiple countries and ministries
    "United States secretaries-of war": "وزراء حرب أمريكيون",
    "secretaries-of defense of egypt": "وزراء دفاع مصريون",
    "secretaries-of interior of united arab emirates": "وزراء داخلية إماراتيون",
    "secretaries-of health of england": "وزراء صحة إنجليز",
    "secretaries-of war": "وزراء حرب",
    "secretaries-of defense": "وزراء دفاع",  # Combined ministries (ministry1 and ministry2)
    "secretaries of health and human services": "وزراء صحة وخدمات إنسانية",
    "secretaries of communications and transportation": "وزراء اتصالات ونقل",
    "secretaries of environment and natural resources": "وزراء بيئة وموارد طبيعية",
    "secretaries of war and navy": "وزراء حرب وبحرية",
    # Combined ministries with countries - Egypt
    "secretaries of health and human services of egypt": "وزراء صحة وخدمات إنسانية مصريون",
    "secretaries of communications and transportation of egypt": "وزراء اتصالات ونقل مصريون",
    "secretaries of environment and natural resources of egypt": "وزراء بيئة وموارد طبيعية مصريون",
    "secretaries of war and navy of egypt": "وزراء حرب وبحرية مصريون",
    # Combined ministries with countries - United Arab Emirates
    "secretaries of health and human services of united arab emirates": "وزراء صحة وخدمات إنسانية إماراتيون",
    "secretaries of communications and transportation of united arab emirates": "وزراء اتصالات ونقل إماراتيون",
    "secretaries of environment and natural resources of united arab emirates": "وزراء بيئة وموارد طبيعية إماراتيون",
    "secretaries of war and navy of united arab emirates": "وزراء حرب وبحرية إماراتيون",
    # Combined ministries with countries - England
    "secretaries of health and human services of england": "وزراء صحة وخدمات إنسانية إنجليز",
    "secretaries of communications and transportation of england": "وزراء اتصالات ونقل إنجليز",
    "secretaries of environment and natural resources of england": "وزراء بيئة وموارد طبيعية إنجليز",
    "secretaries of war and navy of england": "وزراء حرب وبحرية إنجليز",
    # Combined ministries with countries - Ecuador
    "secretaries of health and human services of ecuador": "وزراء صحة وخدمات إنسانية إكوادوريون",
    "secretaries of communications and transportation of ecuador": "وزراء اتصالات ونقل إكوادوريون",
    "secretaries of environment and natural resources of ecuador": "وزراء بيئة وموارد طبيعية إكوادوريون",
    "secretaries of war and navy of ecuador": "وزراء حرب وبحرية إكوادوريون",
    # Combined ministries with countries - Eastern Asia
    "secretaries of health and human services of eastern asia": "وزراء صحة وخدمات إنسانية آسيويون شرقيون",
    "secretaries of communications and transportation of eastern asia": "وزراء اتصالات ونقل آسيويون شرقيون",
    "secretaries of environment and natural resources of eastern asia": "وزراء بيئة وموارد طبيعية آسيويون شرقيون",
    "secretaries of war and navy of eastern asia": "وزراء حرب وبحرية آسيويون شرقيون",
    # Combined ministries with countries - Eastern European
    "secretaries of health and human services of eastern europe": "وزراء صحة وخدمات إنسانية أوروبيون شرقيون",
    "secretaries of communications and transportation of eastern europe": "وزراء اتصالات ونقل أوروبيون شرقيون",
    "secretaries of environment and natural resources of eastern europe": "وزراء بيئة وموارد طبيعية أوروبيون شرقيون",
    "secretaries of war and navy of eastern europe": "وزراء حرب وبحرية أوروبيون شرقيون",
    # Combined ministries with countries - Equatorial Guinea
    "secretaries of health and human services of equatorial guinea": "وزراء صحة وخدمات إنسانية غينيون استوائيون",
    "secretaries of communications and transportation of equatorial guinea": "وزراء اتصالات ونقل غينيون استوائيون",
    "secretaries of environment and natural resources of equatorial guinea": "وزراء بيئة وموارد طبيعية غينيون استوائيون",
    "secretaries of war and navy of equatorial guinea": "وزراء حرب وبحرية غينيون استوائيون",  # Case sensitivity tests
    "SECRETARIES OF DEFENSE OF EGYPT": "وزراء دفاع مصريون",
    "Secretaries Of Defense Of Egypt": "وزراء دفاع مصريون",
    "sEcReTaRiEs Of InTeRiOr Of UnItEd ArAb EmIrAtEs": "وزراء داخلية إماراتيون",
    # Testing with "the" prefix removal
    "secretaries of state of the egypt": "وزراء خارجية مصريون",
    "secretaries of state of the united arab emirates": "وزراء خارجية إماراتيون",
}


@pytest.mark.parametrize("category, expected", fast_data.items(), ids=fast_data.keys())
@pytest.mark.fast
def test_fast_data(category: str, expected: str) -> None:
    label = resolve_secretaries_labels(category)
    assert label == expected



#
import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar

test_jesuits_1 = {
    "16th-century Austrian Jesuits": "يسوعيون نمساويون في القرن 16",
    "16th-century Dutch Jesuits": "يسوعيون هولنديون في القرن 16",
    "16th-century English Jesuits": "يسوعيون إنجليز في القرن 16",
    "16th-century German Jesuits": "يسوعيون ألمان في القرن 16",
    "16th-century Hungarian Jesuits": "يسوعيون مجريون في القرن 16",
    "16th-century Indian Jesuits": "يسوعيون هنود في القرن 16",
    "17th-century Austrian Jesuits": "يسوعيون نمساويون في القرن 17",
    "17th-century Canadian Jesuits": "يسوعيون كنديون في القرن 17",
    "17th-century Dutch Jesuits": "يسوعيون هولنديون في القرن 17",
    "17th-century German Jesuits": "يسوعيون ألمان في القرن 17",
    "17th-century Hungarian Jesuits": "يسوعيون مجريون في القرن 17",
    "17th-century Indian Jesuits": "يسوعيون هنود في القرن 17",
    "18th-century Austrian Jesuits": "يسوعيون نمساويون في القرن 18",
    "18th-century Chilean Jesuits": "يسوعيون تشيليون في القرن 18",
    "17th-century Peruvian Jesuits": "يسوعيون بيرويون في القرن 17",
    "17th-century Welsh Jesuits": "يسوعيون ويلزيون في القرن 17",
    "18th-century Croatian Jesuits": "يسوعيون كروات في القرن 18",
    "18th-century German Jesuits": "يسوعيون ألمان في القرن 18",
    "18th-century Peruvian Jesuits": "يسوعيون بيرويون في القرن 18",
    "18th-century Portuguese Jesuits": "يسوعيون برتغاليون في القرن 18",
    "18th-century Spanish Jesuits": "يسوعيون إسبان في القرن 18",
    "19th-century Austrian Jesuits": "يسوعيون نمساويون في القرن 19",
    "19th-century Belgian Jesuits": "يسوعيون بلجيكيون في القرن 19",
    "19th-century Canadian Jesuits": "يسوعيون كنديون في القرن 19",
    "19th-century Dutch Jesuits": "يسوعيون هولنديون في القرن 19",
    "19th-century German Jesuits": "يسوعيون ألمان في القرن 19",
    "19th-century Irish Jesuits": "يسوعيون أيرلنديون في القرن 19",
    "19th-century Italian Jesuits": "يسوعيون إيطاليون في القرن 19",
    "19th-century Polish Jesuits": "يسوعيون بولنديون في القرن 19",
    "19th-century Spanish Jesuits": "يسوعيون إسبان في القرن 19",
    "20th-century Belgian Jesuits": "يسوعيون بلجيكيون في القرن 20",
    "20th-century Brazilian Jesuits": "يسوعيون برازيليون في القرن 20",
    "20th-century Canadian Jesuits": "يسوعيون كنديون في القرن 20",
    "20th-century Dutch Jesuits": "يسوعيون هولنديون في القرن 20",
    "20th-century Filipino Jesuits": "يسوعيون فلبينيون في القرن 20",
    "20th-century German Jesuits": "يسوعيون ألمان في القرن 20",
    "20th-century Indian Jesuits": "يسوعيون هنود في القرن 20",
    "20th-century Irish Jesuits": "يسوعيون أيرلنديون في القرن 20",
    "20th-century Italian Jesuits": "يسوعيون إيطاليون في القرن 20",
    "20th-century Peruvian Jesuits": "يسوعيون بيرويون في القرن 20",
    "20th-century Polish Jesuits": "يسوعيون بولنديون في القرن 20",
    "20th-century Portuguese Jesuits": "يسوعيون برتغاليون في القرن 20",
    "20th-century Spanish Jesuits": "يسوعيون إسبان في القرن 20",
    "21st-century Belgian Jesuits": "يسوعيون بلجيكيون في القرن 21",
    "21st-century Chilean Jesuits": "يسوعيون تشيليون في القرن 21",
    "21st-century Dutch Jesuits": "يسوعيون هولنديون في القرن 21",
    "21st-century German Jesuits": "يسوعيون ألمان في القرن 21",
    "21st-century Indian Jesuits": "يسوعيون هنود في القرن 21",
    "21st-century Italian Jesuits": "يسوعيون إيطاليون في القرن 21",
    "21st-century Spanish Jesuits": "يسوعيون إسبان في القرن 21",
    "Australian Jesuits": "يسوعيون أستراليون",
    "Basque Jesuits": "يسوعيون باسكيون",
    "Belizean Jesuits": "يسوعيون بليزيون",
    "Colombian Jesuits": "يسوعيون كولومبيون",
    "Cuban Jesuits": "يسوعيون كوبيون",
    "Dutch Jesuits": "يسوعيون هولنديون",
    "Ecuadorian Jesuits": "يسوعيون إكوادوريون",
    "Filipino Jesuits": "يسوعيون فلبينيون",
    "Guyanese Jesuits": "يسوعيون غيانيون",
    "Hong Kong Jesuits": "يسوعيون هونغ كونغيون",
    "Hungarian Jesuits": "يسوعيون مجريون",
    "Indian Jesuits": "يسوعيون هنود",
    "Indonesian Jesuits": "يسوعيون إندونيسيون",
    "Irish Jesuits": "يسوعيون أيرلنديون",
    "Israeli Jesuits": "يسوعيون إسرائيليون",
    "Jamaican Jesuits": "يسوعيون جامايكيون",
    "Jesuits by century": "يسوعيون حسب القرن",
    "Jesuits from the Austrian Netherlands": "يسوعيون من الأراضي المنخفضة النمساوية",
    "Jesuits from the Canary Islands": "يسوعيون من جزر الكناري",
    "Jesuits from the Spanish Netherlands": "يسوعيون من هولندا الإسبانية",
    "Lebanese Jesuits": "يسوعيون لبنانيون",
    "Luxembourgian Jesuits": "يسوعيون لوكسمبورغيون",
    "Malaysian Jesuits": "يسوعيون ماليزيون",
    "Maltese Jesuits": "يسوعيون مالطيون",
    "Mexican Jesuits": "يسوعيون مكسيكيون",
    "Nepalese Jesuits": "يسوعيون نيباليون",
    "New Zealand Jesuits": "يسوعيون نيوزيلنديون",
    "Nicaraguan Jesuits": "يسوعيون نيكاراغويون",
    "Salvadoran Jesuits": "يسوعيون سلفادوريون",
    "Slovenian Jesuits": "يسوعيون سلوفينيون",
    "Sri Lankan Jesuits": "يسوعيون سريلانكيون",
    "Swiss Jesuits": "يسوعيون سويسريون",
    "Venezuelan Jesuits": "يسوعيون فنزويليون",
    "Welsh Jesuits": "يسوعيون ويلزيون",
}

test_jesuits_2 = {
    "16th-century French Jesuits": "يسوعيون فرنسيون في القرن 16",
    "16th-century Italian Jesuits": "يسوعيون إيطاليون في القرن 16",
    "16th-century Jesuits": "يسوعيون في القرن 16",
    "16th-century Portuguese Jesuits": "يسوعيون برتغاليون في القرن 16",
    "16th-century Spanish Jesuits": "يسوعيون إسبان في القرن 16",
    "17th-century Belgian Jesuits": "يسوعيون بلجيكيون في القرن 17",
    "17th-century Chilean Jesuits": "يسوعيون تشيليون في القرن 17",
    "17th-century English Jesuits": "يسوعيون إنجليز في القرن 17",
    "17th-century French Jesuits": "يسوعيون فرنسيون في القرن 17",
    "17th-century Italian Jesuits": "يسوعيون إيطاليون في القرن 17",
    "17th-century Jesuits": "يسوعيون في القرن 17",
    "17th-century Portuguese Jesuits": "يسوعيون برتغاليون في القرن 17",
    "17th-century Spanish Jesuits": "يسوعيون إسبان في القرن 17",
    "18th-century American Jesuits": "يسوعيون أمريكيون في القرن 18",
    "18th-century Italian Jesuits": "يسوعيون إيطاليون في القرن 18",
    "18th-century Jesuits": "يسوعيون في القرن 18",
    "19th-century American Jesuits": "يسوعيون أمريكيون في القرن 19",
    "19th-century Chilean Jesuits": "يسوعيون تشيليون في القرن 19",
    "19th-century English Jesuits": "يسوعيون إنجليز في القرن 19",
    "19th-century French Jesuits": "يسوعيون فرنسيون في القرن 19",
    "19th-century Jesuits": "يسوعيون في القرن 19",
    "20th-century American Jesuits": "يسوعيون أمريكيون في القرن 20",
    "20th-century Chilean Jesuits": "يسوعيون تشيليون في القرن 20",
    "20th-century English Jesuits": "يسوعيون إنجليز في القرن 20",
    "20th-century French Jesuits": "يسوعيون فرنسيون في القرن 20",
    "20th-century Jesuits": "يسوعيون في القرن 20",
    "21st-century American Jesuits": "يسوعيون أمريكيون في القرن 21",
    "21st-century French Jesuits": "يسوعيون فرنسيون في القرن 21",
    "21st-century Jesuits": "يسوعيون في القرن 21",
    "American Jesuits": "يسوعيون أمريكيون",
    "Argentine Jesuits": "يسوعيون أرجنتينيون",
    "Austrian Jesuits": "يسوعيون نمساويون",
    "Belgian Jesuits": "يسوعيون بلجيكيون",
    "Brazilian Jesuits": "يسوعيون برازيليون",
    "British Jesuits": "يسوعيون بريطانيون",
    "Canadian Jesuits": "يسوعيون كنديون",
    "Chilean Jesuits": "يسوعيون تشيليون",
    "Chinese Jesuits": "يسوعيون صينيون",
    "Croatian Jesuits": "يسوعيون كروات",
    "Czech Jesuits": "يسوعيون تشيكيون",
    "Egyptian Jesuits": "يسوعيون مصريون",
    "English Jesuits": "يسوعيون إنجليز",
    "French Jesuits": "يسوعيون فرنسيون",
    "German Jesuits": "يسوعيون ألمان",
    "Italian Jesuits": "يسوعيون إيطاليون",
    "Japanese Jesuits": "يسوعيون يابانيون",
    "Jesuits by nationality": "يسوعيون حسب الجنسية",
    "Peruvian Jesuits": "يسوعيون بيرويون",
    "Polish Jesuits": "يسوعيون بولنديون",
    "Portuguese Jesuits": "يسوعيون برتغاليون",
    "Spanish Jesuits": "يسوعيون إسبان",
}

to_test = [
    ("test_jesuits_1", test_jesuits_1),
    ("test_jesuits_2", test_jesuits_2),
]


@pytest.mark.parametrize("category, expected", test_jesuits_2.items(), ids=test_jesuits_2.keys())
@pytest.mark.fast
def test_data_jesuits_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    # dump_same_and_not_same(data, diff_result, name, True)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""

"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.nationalities_and_sports import resolve_nats_sport_multi_v2

en_is_nat_ar_is_P17_data = {
    "yemeni acrobatic gymnastics cup": "كأس اليمن للجمباز الاكروباتيكي",
    "yemeni acrobatic gymnastics racing cup": "كأس اليمن لسباق الجمباز الاكروباتيكي",
    "yemeni aerobics cup": "كأس اليمن لجمباز أيروبيكس",
    "yemeni aerobics racing cup": "كأس اليمن لسباق جمباز أيروبيكس",
    "yemeni alpine skiing cup": "كأس اليمن للتزلج على المنحدرات الثلجية",
    "yemeni alpine skiing racing cup": "كأس اليمن لسباق التزلج على المنحدرات الثلجية",
    "yemeni women's australian rules football cup": "كأس اليمن لكرة القدم الأسترالية للسيدات",
    "yemeni women's australian rules football racing cup": "كأس اليمن لسباق كرة القدم الأسترالية للسيدات",
    "yemeni women's auto racing cup": "كأس اليمن لسباق السيارات للسيدات",
    "yemeni women's automobile racing cup": "كأس اليمن لسباق السيارات للسيدات",
    "yemeni women's badminton cup": "كأس اليمن لتنس الريشة للسيدات",
    "yemeni women's badminton racing cup": "كأس اليمن لسباق تنس الريشة للسيدات",
    "yemeni women's ball hockey cup": "كأس اليمن لهوكي الكرة للسيدات",
    "yemeni women's ball hockey racing cup": "كأس اليمن لسباق هوكي الكرة للسيدات",
    "yemeni women's bandy cup": "كأس اليمن للباندي للسيدات",
    "yemeni women's bandy racing cup": "كأس اليمن لسباق باندي للسيدات",
    "yemeni women's baseball cup": "كأس اليمن لكرة القاعدة للسيدات",
    "yemeni women's baseball racing cup": "كأس اليمن لسباق كرة القاعدة للسيدات",
    "yemeni women's basketball cup": "كأس اليمن لكرة السلة للسيدات",
    "yemeni women's basketball racing cup": "كأس اليمن لسباق كرة السلة للسيدات",
    "yemeni women's basque pelota cup": "كأس اليمن لكرة الباسك للسيدات",
    "yemeni women's basque pelota racing cup": "كأس اليمن لسباق كرة الباسك للسيدات",
    "yemeni women's beach handball cup": "كأس اليمن لكرة اليد الشاطئية للسيدات",
    "yemeni women's beach handball racing cup": "كأس اليمن لسباق كرة اليد الشاطئية للسيدات",
    "yemeni women's beach soccer cup": "كأس اليمن لكرة القدم الشاطئية للسيدات",
    "yemeni women's beach soccer racing cup": "كأس اليمن لسباق كرة القدم الشاطئية للسيدات",
    "yemeni women's beach volleyball cup": "كأس اليمن لكرة الطائرة الشاطئية للسيدات",
    "yemeni women's beach volleyball racing cup": "كأس اليمن لسباق كرة الطائرة الشاطئية للسيدات",
    "yemeni women's biathlon cup": "كأس اليمن للبياثلون للسيدات",
    "yemeni women's biathlon racing cup": "كأس اليمن لسباق البياثلون للسيدات",
    "yemeni women's bicycle motocross cup": "كأس اليمن للبي ام اكس للسيدات",
    "yemeni women's bicycle motocross racing cup": "كأس اليمن لسباق بي ام اكس للسيدات",
    "yemeni women's bmx cup": "كأس اليمن لسباق البي إم إكس للسيدات",
    "yemeni women's bmx racing cup": "كأس اليمن لسباق البي إم إكس للسيدات",
    "yemeni women's board games cup": "كأس اليمن لألعاب الطاولة للسيدات",
    "yemeni women's board games racing cup": "كأس اليمن لسباق ألعاب الطاولة للسيدات",
    "yemeni women's boat racing cup": "كأس اليمن لسباق الزوارق للسيدات",
    "yemeni women's bobsleigh cup": "كأس اليمن للزلاجة الجماعية للسيدات",
    "yemeni women's bobsleigh racing cup": "كأس اليمن لسباق الزلاجة الجماعية للسيدات",
    "yemeni women's boccia cup": "كأس اليمن للبوتشيا للسيدات",
    "yemeni women's boccia racing cup": "كأس اليمن لسباق البوتشيا للسيدات",
    "yemeni women's bodybuilding cup": "كأس اليمن لكمال الأجسام للسيدات",
    "yemeni women's bodybuilding racing cup": "كأس اليمن لسباق كمال الأجسام للسيدات",
    "yemeni women's bouldering cup": "كأس اليمن للبولدرنق للسيدات",
    "yemeni women's bouldering racing cup": "كأس اليمن لسباق بولدرنق للسيدات",
    "yemeni women's boules cup": "كأس اليمن للبوتشي للسيدات",
    "yemeni women's boules racing cup": "كأس اليمن لسباق بوتشي للسيدات",
    "yemeni women's bowling cup": "كأس اليمن للبولينج للسيدات",
    "yemeni women's bowling racing cup": "كأس اليمن لسباق بولينج للسيدات",
    "yemeni women's bowls cup": "كأس اليمن للبولينج للسيدات",
    "yemeni women's bowls racing cup": "كأس اليمن لسباق البولينج للسيدات",
    "yemeni women's boxing cup": "كأس اليمن للبوكسينغ للسيدات",
    "yemeni women's boxing racing cup": "كأس اليمن لسباق البوكسينغ للسيدات",
    "yemeni women's bullfighting cup": "كأس اليمن لمصارعة الثيران للسيدات",
    "yemeni women's bullfighting racing cup": "كأس اليمن لسباق مصارعة الثيران للسيدات",
    "yemeni women's canadian football cup": "كأس اليمن لكرة القدم الكندية للسيدات",
    "yemeni women's canadian football racing cup": "كأس اليمن لسباق كرة القدم الكندية للسيدات",
    "yemeni women's canadian-football cup": "كأس اليمن لكرة القدم الكندية للسيدات",
    "yemeni women's canadian-football racing cup": "كأس اليمن لسباق كرة القدم الكندية للسيدات",
    "yemeni women's canoe sprint cup": "كأس اليمن لسباق القوارب للسيدات",
    "yemeni women's canoeing and kayaking cup": "كأس اليمن للكانو كاياك للسيدات",
    "yemeni women's canoeing and kayaking racing cup": "كأس اليمن لسباق كانو-كاياك للسيدات",
    "yemeni women's canoeing cup": "كأس اليمن لركوب الكنو للسيدات",
    "yemeni women's canoeing racing cup": "كأس اليمن لسباق ركوب الكنو للسيدات",
    "yemeni women's chess cup": "كأس اليمن للشطرنج للسيدات",
    "yemeni women's chess racing cup": "كأس اليمن لسباق الشطرنج للسيدات",
    "yemeni women's chinese martial arts cup": "كأس اليمن للفنون القتالية الصينية للسيدات",
    "yemeni women's chinese martial arts racing cup": "كأس اليمن لسباق الفنون القتالية الصينية للسيدات",
    "yemeni women's climbing cup": "كأس اليمن للتسلق للسيدات",
    "yemeni women's climbing racing cup": "كأس اليمن لسباق التسلق للسيدات",
    "yemeni women's college cup": "كأس اليمن للكليات للسيدات",
    "yemeni women's college racing cup": "كأس اليمن لسباق الكليات للسيدات",
    "yemeni women's cricket cup": "كأس اليمن للكريكت للسيدات",
    "yemeni women's cricket racing cup": "كأس اليمن لسباق الكريكت للسيدات",
    "yemeni women's croquet cup": "كأس اليمن للكروكيت للسيدات",
    "yemeni women's croquet racing cup": "كأس اليمن لسباق الكروكيت للسيدات",
    "yemeni women's cross country cup": "كأس اليمن للعدو الريفي للسيدات",
    "yemeni women's cross country racing cup": "كأس اليمن لسباق العدو الريفي للسيدات",
    "yemeni women's cross country running cup": "كأس اليمن للعدو الريفي للسيدات",
    "yemeni women's cross country running racing cup": "كأس اليمن لسباق العدو الريفي للسيدات",
    "yemeni women's cross-country skiing cup": "كأس اليمن للتزلج الريفي للسيدات",
    "yemeni women's cross-country skiing racing cup": "كأس اليمن لسباق التزلج الريفي للسيدات",
    "yemeni women's cue sports cup": "كأس اليمن للبلياردو للسيدات",
    "yemeni women's cue sports racing cup": "كأس اليمن لسباق بلياردو للسيدات",
    "yemeni women's curling cup": "كأس اليمن للكيرلنغ للسيدات",
    "yemeni women's curling racing cup": "كأس اليمن لسباق الكيرلنغ للسيدات",
    "yemeni women's cycle cup": "كأس اليمن للدراجات للسيدات",
    "yemeni women's cycle race cup": "كأس اليمن لسباق الدراجات للسيدات",
    "yemeni women's cycle racing cup": "كأس اليمن لسباق الدراجات للسيدات",
    "yemeni women's cycle speedway cup": "كأس اليمن لسباق الدراجات النارية على المنعطفات للسيدات",
    "yemeni women's cycling cup": "كأس اليمن لسباق الدراجات الهوائية للسيدات",
    "yemeni women's cycling road race cup": "كأس اليمن لسباق الدراجات على الطريق للسيدات",
    "yemeni women's cyclo-cross cup": "كأس اليمن للسيكلو كروس للسيدات",
    "yemeni women's cyclo-cross racing cup": "كأس اليمن لسباق سيكلو كروس للسيدات",
    "yemeni women's darts cup": "كأس اليمن للسهام المريشة للسيدات",
    "yemeni women's darts racing cup": "كأس اليمن لسباق السهام المريشة للسيدات",
    "yemeni women's davis cup cup": "كأس اليمن لكأس ديفيز للسيدات",
    "yemeni women's davis cup racing cup": "كأس اليمن لسباق كأس ديفيز للسيدات",
    "yemeni women's discus throw cup": "كأس اليمن لرمي القرص للسيدات",
    "yemeni women's discus throw racing cup": "كأس اليمن لسباق رمي القرص للسيدات",
    "yemeni women's diving cup": "كأس اليمن للغطس للسيدات",
    "yemeni women's diving racing cup": "كأس اليمن لسباق الغطس للسيدات",
    "yemeni women's dragon boat cup": "كأس اليمن لسباق قوارب التنين للسيدات",
    "yemeni women's dragon boat racing cup": "كأس اليمن لسباق قوارب التنين للسيدات",
    "yemeni women's draughts cup": "كأس اليمن للضامة للسيدات",
    "yemeni women's draughts racing cup": "كأس اليمن لسباق ضامة للسيدات",
    "yemeni women's dressage cup": "كأس اليمن لترويض الخيول للسيدات",
    "yemeni women's dressage racing cup": "كأس اليمن لسباق ترويض الخيول للسيدات",
    "yemeni women's equestrian cup": "كأس اليمن للفروسية للسيدات",
    "yemeni women's equestrian racing cup": "كأس اليمن لسباق الفروسية للسيدات",
    "yemeni women's equestrianism cup": "كأس اليمن للفروسية للسيدات",
    "yemeni women's equestrianism racing cup": "كأس اليمن لسباق الفروسية للسيدات",
    "yemeni women's esports cup": "كأس اليمن للرياضة الإلكترونية للسيدات",
    "yemeni women's esports racing cup": "كأس اليمن لسباق رياضة إلكترونية للسيدات",
    "yemeni women's eventing cup": "كأس اليمن لمحاكمة الخيول للسيدات",
    "yemeni women's eventing racing cup": "كأس اليمن لسباق محاكمة الخيول للسيدات",
    "yemeni women's fencing cup": "كأس اليمن لمبارزة سيف الشيش للسيدات",
    "yemeni women's fencing racing cup": "كأس اليمن لسباق مبارزة سيف الشيش للسيدات",
    "yemeni women's field hockey cup": "كأس اليمن لهوكي الميدان للسيدات",
    "yemeni women's field hockey racing cup": "كأس اليمن لسباق هوكي الميدان للسيدات",
    "yemeni women's fifa futsal world cup cup": "كأس اليمن لكأس العالم لكرة الصالات للسيدات",
    "yemeni women's fifa futsal world cup racing cup": "كأس اليمن لسباق كأس العالم لكرة الصالات للسيدات",
    "yemeni women's fifa world cup cup": "كأس اليمن لكأس العالم لكرة القدم للسيدات",
    "yemeni women's fifa world cup racing cup": "كأس اليمن لسباق كأس العالم لكرة القدم للسيدات",
    "yemeni women's figure skating cup": "كأس اليمن للتزلج الفني للسيدات",
    "yemeni women's figure skating racing cup": "كأس اليمن لسباق التزلج الفني للسيدات",
    "yemeni women's floorball cup": "كأس اليمن لكرة الأرض للسيدات",
    "yemeni women's floorball racing cup": "كأس اليمن لسباق كرة الأرض للسيدات",
    "yemeni women's football cup": "كأس اليمن لكرة القدم للسيدات",
    "yemeni women's football racing cup": "كأس اليمن لسباق كرة القدم للسيدات",
    "yemeni women's formula e cup": "كأس اليمن للفورمولا إي للسيدات",
    "yemeni women's formula e racing cup": "كأس اليمن لسباق فورمولا إي للسيدات",
    "yemeni women's formula one cup": "كأس اليمن للفورمولا ون للسيدات",
    "yemeni women's formula one racing cup": "كأس اليمن لسباق فورمولا ون للسيدات",
    "yemeni women's formula racing cup": "كأس اليمن لسباقات الفورمولا للسيدات",
    "yemeni women's freestyle skiing cup": "كأس اليمن للتزلج الحر للسيدات",
    "yemeni women's freestyle skiing racing cup": "كأس اليمن لسباق التزلج الحر للسيدات",
    "yemeni women's freestyle wrestling cup": "كأس اليمن للمصارعة الحرة للسيدات",
    "yemeni women's freestyle wrestling racing cup": "كأس اليمن لسباق المصارعة الحرة للسيدات",
    "yemeni women's futsal cup": "كأس اليمن لكرة الصالات للسيدات",
    "yemeni women's futsal racing cup": "كأس اليمن لسباق كرة صالات للسيدات",
    "yemeni women's gaelic football cup": "كأس اليمن لكرة القدم الغالية للسيدات",
    "yemeni women's gaelic football racing cup": "كأس اليمن لسباق كرة القدم الغالية للسيدات",
    "yemeni women's go cup": "كأس اليمن للغو للسيدات",
    "yemeni women's go racing cup": "كأس اليمن لسباق غو للسيدات",
    "yemeni women's goalball cup": "كأس اليمن لكرة الهدف للسيدات",
    "yemeni women's goalball racing cup": "كأس اليمن لسباق كرة الهدف للسيدات",
    "yemeni women's golf cup": "كأس اليمن للغولف للسيدات",
    "yemeni women's golf racing cup": "كأس اليمن لسباق الغولف للسيدات",
    "yemeni women's greco-roman wrestling cup": "كأس اليمن للمصارعة اليونانية الرومانية للسيدات",
    "yemeni women's greco-roman wrestling racing cup": "كأس اليمن لسباق المصارعة اليونانية الرومانية للسيدات",
    "yemeni women's gridiron football cup": "كأس اليمن لكرة القدم الأمريكية الشمالية للسيدات",
    "yemeni women's gridiron football racing cup": "كأس اليمن لسباق كرة القدم الأمريكية الشمالية للسيدات",
    "yemeni women's gymnastics cup": "كأس اليمن للجمباز للسيدات",
    "yemeni women's gymnastics racing cup": "كأس اليمن لسباق الجمباز للسيدات",
    "yemeni women's hammer throw cup": "كأس اليمن لرمي المطرقة للسيدات",
    "yemeni women's hammer throw racing cup": "كأس اليمن لسباق رمي المطرقة للسيدات",
    "yemeni women's handball cup": "كأس اليمن لكرة اليد للسيدات",
    "yemeni women's handball racing cup": "كأس اليمن لسباق كرة اليد للسيدات",
    "yemeni women's high jump cup": "كأس اليمن للقفز العالي للسيدات",
    "yemeni women's high jump racing cup": "كأس اليمن لسباق القفز العالي للسيدات",
    "yemeni women's high school cup": "كأس اليمن للمدارس الثانوية للسيدات",
    "yemeni women's high school racing cup": "كأس اليمن لسباق المدارس الثانوية للسيدات",
    "yemeni women's hockey cup": "كأس اليمن للهوكي للسيدات",
    "yemeni women's hockey racing cup": "كأس اليمن لسباق هوكي للسيدات",
    "yemeni women's hurling cup": "كأس اليمن للقذف للسيدات",
    "yemeni women's hurling racing cup": "كأس اليمن لسباق القذف للسيدات",
    "yemeni women's ice dancing cup": "كأس اليمن للرقص على الجليد للسيدات",
    "yemeni women's ice dancing racing cup": "كأس اليمن لسباق الرقص على الجليد للسيدات",
    "yemeni women's ice hockey cup": "كأس اليمن لهوكي الجليد للسيدات",
    "yemeni women's ice hockey racing cup": "كأس اليمن لسباق هوكي الجليد للسيدات",
    "yemeni women's ice skating cup": "كأس اليمن للتزلج على الجليد للسيدات",
    "yemeni women's ice skating racing cup": "كأس اليمن لسباق تزلج على الجليد للسيدات",
    "yemeni women's ice sledge hockey cup": "كأس اليمن لهوكي المزلجة على الجليد للسيدات",
    "yemeni women's ice sledge hockey racing cup": "كأس اليمن لسباق هوكي المزلجة على الجليد للسيدات",
    "yemeni women's inline hockey cup": "كأس اليمن للهوكي المضمن للسيدات",
    "yemeni women's inline hockey racing cup": "كأس اليمن لسباق هوكي مضمن للسيدات",
    "yemeni women's javelin throw cup": "كأس اليمن لرمي الرمح للسيدات",
    "yemeni women's javelin throw racing cup": "كأس اليمن لسباق رمي الرمح للسيدات",
    "yemeni women's ju-jitsu cup": "كأس اليمن للجوجوتسو للسيدات",
    "yemeni women's ju-jitsu racing cup": "كأس اليمن لسباق جوجوتسو للسيدات",
    "yemeni women's judo cup": "كأس اليمن للجودو للسيدات",
    "yemeni women's judo racing cup": "كأس اليمن لسباق الجودو للسيدات",
    "yemeni women's jujutsu cup": "كأس اليمن للجوجوتسو للسيدات",
    "yemeni women's jujutsu racing cup": "كأس اليمن لسباق جوجوتسو للسيدات",
    "yemeni women's kabaddi cup": "كأس اليمن للكابادي للسيدات",
    "yemeni women's kabaddi racing cup": "كأس اليمن لسباق الكابادي للسيدات",
    "yemeni women's karate cup": "كأس اليمن للكاراتيه للسيدات",
    "yemeni women's karate racing cup": "كأس اليمن لسباق الكاراتيه للسيدات",
    "yemeni women's kick boxing cup": "كأس اليمن للكيك بوكسينغ للسيدات",
    "yemeni women's kick boxing racing cup": "كأس اليمن لسباق الكيك بوكسينغ للسيدات",
    "yemeni women's kickboxing cup": "كأس اليمن للكيك بوكسينغ للسيدات",
    "yemeni women's kickboxing racing cup": "كأس اليمن لسباق الكيك بوكسينغ للسيدات",
    "yemeni women's korfball cup": "كأس اليمن للكورفبال للسيدات",
    "yemeni women's korfball racing cup": "كأس اليمن لسباق كورفبال للسيدات",
    "yemeni women's kurash cup": "كأس اليمن للكوراش للسيدات",
    "yemeni women's kurash racing cup": "كأس اليمن لسباق كوراش للسيدات",
    "yemeni women's lacrosse racing cup": "كأس اليمن لسباق لاكروس للسيدات",
    "yemeni women's lawn bowls cup": "كأس اليمن للبولينغ العشبي للسيدات",
    "yemeni women's lawn bowls racing cup": "كأس اليمن لسباق البولينغ العشبي للسيدات",
    "yemeni women's long jump cup": "كأس اليمن للقفز الطويل للسيدات",
    "yemeni women's long jump racing cup": "كأس اليمن لسباق القفز الطويل للسيدات",
    "yemeni women's long-distance running cup": "كأس اليمن لركض المسافات الطويلة للسيدات",
    "yemeni women's long-distance running racing cup": "كأس اليمن لسباق ركض المسافات الطويلة للسيدات",
    "yemeni women's luge cup": "كأس اليمن للزحف الثلجي للسيدات",
    "yemeni women's luge racing cup": "كأس اليمن لسباق الزحف الثلجي للسيدات",
    "yemeni women's marathon running cup": "كأس اليمن لسباق الماراثون للسيدات",
    "yemeni women's martial arts cup": "كأس اليمن للفنون القتالية للسيدات",
    "yemeni women's martial arts racing cup": "كأس اليمن لسباق الفنون القتالية للسيدات",
    "yemeni women's middle-distance running cup": "كأس اليمن لركض المسافات المتوسطة للسيدات",
    "yemeni women's middle-distance running racing cup": "كأس اليمن لسباق ركض المسافات المتوسطة للسيدات",
    "yemeni women's mixed martial arts cup": "كأس اليمن لفنون القتال المختلطة للسيدات",
    "yemeni women's mixed martial arts racing cup": "كأس اليمن لسباق فنون القتال المختلطة للسيدات",
    "yemeni women's modern pentathlon cup": "كأس اليمن للخماسي الحديث للسيدات",
    "yemeni women's modern pentathlon racing cup": "كأس اليمن لسباق الخماسي الحديث للسيدات",
    "yemeni women's motocross cup": "كأس اليمن للموتو كروس للسيدات",
    "yemeni women's motocross racing cup": "كأس اليمن لسباق موتو كروس للسيدات",
    "yemeni women's motor cup": "كأس اليمن للمحركات للسيدات",
    "yemeni women's motor racing cup": "كأس اليمن لسباق المحركات للسيدات",
    "yemeni women's motorboat cup": "كأس اليمن للزوارق النارية للسيدات",
    "yemeni women's motorboat racing cup": "كأس اليمن لسباق الزوارق النارية للسيدات",
    "yemeni women's motorcycle cup": "كأس اليمن للدراجات النارية للسيدات",
    "yemeni women's motorcycle racing cup": "كأس اليمن لسباق الدراجات النارية للسيدات",
    "yemeni women's motorsport cup": "كأس اليمن لرياضة المحركات للسيدات",
    "yemeni women's motorsport racing cup": "كأس اليمن لسباق رياضة المحركات للسيدات",
    "yemeni women's motorsports cup": "كأس اليمن لرياضة المحركات للسيدات",
    "yemeni women's motorsports racing cup": "كأس اليمن لسباق رياضة المحركات للسيدات",
    "yemeni women's mountain bike cup": "كأس اليمن لسباق الدراجات الجبلية للسيدات",
    "yemeni women's mountain bike racing cup": "كأس اليمن لسباق الدراجات الجبلية للسيدات",
    "yemeni women's muay thai cup": "كأس اليمن للموياي تاي للسيدات",
    "yemeni women's muay thai racing cup": "كأس اليمن لسباق موياي تاي للسيدات",
    "yemeni women's netball cup": "كأس اليمن لكرة الشبكة للسيدات",
    "yemeni women's netball racing cup": "كأس اليمن لسباق كرة الشبكة للسيدات",
    "yemeni women's nordic combined cup": "كأس اليمن للتزلج النوردي المزدوج للسيدات",
    "yemeni women's nordic combined racing cup": "كأس اليمن لسباق التزلج النوردي المزدوج للسيدات",
    "yemeni women's orienteering cup": "كأس اليمن لسباق الموجه للسيدات",
    "yemeni women's pair skating cup": "كأس اليمن للتزلج الفني على الجليد للسيدات",
    "yemeni women's pair skating racing cup": "كأس اليمن لسباق التزلج الفني على الجليد للسيدات",
    "yemeni women's pencak silat cup": "كأس اليمن للبنكات سيلات للسيدات",
    "yemeni women's pencak silat racing cup": "كأس اليمن لسباق بنكات سيلات للسيدات",
    "yemeni women's pentathlon cup": "كأس اليمن للخماسي للسيدات",
    "yemeni women's pentathlon racing cup": "كأس اليمن لسباق الخماسي للسيدات",
    "yemeni women's pesäpallo cup": "كأس اليمن للبيسبالو للسيدات",
    "yemeni women's pesäpallo racing cup": "كأس اليمن لسباق بيسبالو للسيدات",
    "yemeni women's poker cup": "كأس اليمن للبوكر للسيدات",
    "yemeni women's poker racing cup": "كأس اليمن لسباق البوكر للسيدات",
    "yemeni women's pole vault cup": "كأس اليمن للقفز بالزانة للسيدات",
    "yemeni women's pole vault racing cup": "كأس اليمن لسباق القفز بالزانة للسيدات",
    "yemeni women's polo cup": "كأس اليمن للبولو للسيدات",
    "yemeni women's polo racing cup": "كأس اليمن لسباق البولو للسيدات",
    "yemeni women's powerlifting cup": "كأس اليمن لرياضة القوة للسيدات",
    "yemeni women's powerlifting racing cup": "كأس اليمن لسباق رياضة القوة للسيدات",
    "yemeni women's professional wrestling cup": "كأس اليمن لمصارعة المحترفين للسيدات",
    "yemeni women's professional wrestling racing cup": "كأس اليمن لسباق مصارعة المحترفين للسيدات",
    "yemeni women's racewalking cup": "كأس اليمن لسباق الجري للسيدات",
    "yemeni women's racingxx cup": "كأس اليمن لسباق السيارات للسيدات",
    "yemeni women's racquetball cup": "كأس اليمن لكرة الراح للسيدات",
    "yemeni women's racquetball racing cup": "كأس اليمن لسباق كرة الراح للسيدات",
    "yemeni women's racquets cup": "كأس اليمن للعبة الراح للسيدات",
    "yemeni women's racquets racing cup": "كأس اليمن لسباق لعبة الراح للسيدات",
    "yemeni women's rally cup": "كأس اليمن للرالي للسيدات",
    "yemeni women's rally racing cup": "كأس اليمن لسباق الرالي للسيدات",
    "yemeni women's rally raid cup": "كأس اليمن للرالي رايد للسيدات",
    "yemeni women's rally raid racing cup": "كأس اليمن لسباق الرالي رايد للسيدات",
    "yemeni women's rallying cup": "كأس اليمن للراليات للسيدات",
    "yemeni women's rallying racing cup": "كأس اليمن لسباق الراليات للسيدات",
    "yemeni women's relay race cup": "كأس اليمن لسباق التتابع للسيدات",
    "yemeni women's rhythmic gymnastics cup": "كأس اليمن للجمباز الإيقاعي للسيدات",
    "yemeni women's rhythmic gymnastics racing cup": "كأس اليمن لسباق الجمباز الإيقاعي للسيدات",
    "yemeni women's rifle shooting cup": "كأس اليمن لرماية البندقية للسيدات",
    "yemeni women's rifle shooting racing cup": "كأس اليمن لسباق رماية البندقية للسيدات",
    "yemeni women's road bicycle racing cup": "كأس اليمن لسباق الدراجات على الطريق للسيدات",
    "yemeni women's road cycling cup": "كأس اليمن لسباق الدراجات على الطريق للسيدات",
    "yemeni women's road race cup": "كأس اليمن لسباق الدراجات على الطريق للسيدات",
    "yemeni women's roller hockey (quad) cup": "كأس اليمن لهوكي الدحرجة للسيدات",
    "yemeni women's roller hockey (quad) racing cup": "كأس اليمن لسباق هوكي الدحرجة للسيدات",
    "yemeni women's roller hockey cup": "كأس اليمن لهوكي الدحرجة للسيدات",
    "yemeni women's roller hockey racing cup": "كأس اليمن لسباق هوكي الدحرجة للسيدات",
    "yemeni women's roller skating cup": "كأس اليمن للتزلج بالعجلات للسيدات",
    "yemeni women's roller skating racing cup": "كأس اليمن لسباق التزلج بالعجلات للسيدات",
    "yemeni women's rowing cup": "كأس اليمن للتجديف للسيدات",
    "yemeni women's rowing racing cup": "كأس اليمن لسباق التجديف للسيدات",
    "yemeni women's rugby cup": "كأس اليمن للرجبي للسيدات",
    "yemeni women's rugby football cup": "كأس اليمن لكرة قدم الرجبي للسيدات",
    "yemeni women's rugby football racing cup": "كأس اليمن لسباق كرة قدم الرجبي للسيدات",
    "yemeni women's rugby league cup": "كأس اليمن لدوري الرجبي للسيدات",
    "yemeni women's rugby league racing cup": "كأس اليمن لسباق دوري الرجبي للسيدات",
    "yemeni women's rugby racing cup": "كأس اليمن لسباق الرجبي للسيدات",
    "yemeni women's rugby sevens cup": "كأس اليمن لسباعيات الرجبي للسيدات",
    "yemeni women's rugby sevens racing cup": "كأس اليمن لسباق سباعيات الرجبي للسيدات",
    "yemeni women's rugby union cup": "كأس اليمن لاتحاد الرجبي للسيدات",
    "yemeni women's rugby union racing cup": "كأس اليمن لسباق اتحاد الرجبي للسيدات",
    "yemeni women's rugbyunion cup": "كأس اليمن لاتحاد الرجبي للسيدات",
    "yemeni women's rugbyunion racing cup": "كأس اليمن لسباق اتحاد الرجبي للسيدات",
    "yemeni women's running cup": "كأس اليمن للركض للسيدات",
    "yemeni women's running racing cup": "كأس اليمن لسباق الركض للسيدات",
    "yemeni women's sailing (sport) cup": "كأس اليمن لرياضة الإبحار للسيدات",
    "yemeni women's sailing (sport) racing cup": "كأس اليمن لسباق رياضة الإبحار للسيدات",
    "yemeni women's sailing cup": "كأس اليمن للإبحار للسيدات",
    "yemeni women's sailing racing cup": "كأس اليمن لسباق الإبحار للسيدات",
    "yemeni women's sambo cup": "كأس اليمن للسامبو للسيدات",
    "yemeni women's sambo racing cup": "كأس اليمن لسباق سامبو للسيدات",
    "yemeni women's sepak takraw cup": "كأس اليمن للسيباك تاكرو للسيدات",
    "yemeni women's sepak takraw racing cup": "كأس اليمن لسباق سيباك تاكرو للسيدات",
    "yemeni women's shooting cup": "كأس اليمن للرماية للسيدات",
    "yemeni women's shooting racing cup": "كأس اليمن لسباق الرماية للسيدات",
    "yemeni women's shooting sport cup": "كأس اليمن للرماية للسيدات",
    "yemeni women's shooting sport racing cup": "كأس اليمن لسباق الرماية للسيدات",
    "yemeni women's shooting sports cup": "كأس اليمن للرماية للسيدات",
    "yemeni women's shooting sports racing cup": "كأس اليمن لسباق الرماية للسيدات",
    "yemeni women's short track speed skating cup": "كأس اليمن للتزلج على مسار قصير للسيدات",
    "yemeni women's short track speed skating racing cup": "كأس اليمن لسباق التزلج على مسار قصير للسيدات",
    "yemeni women's shot put cup": "كأس اليمن لدفع الثقل للسيدات",
    "yemeni women's shot put racing cup": "كأس اليمن لسباق دفع الثقل للسيدات",
    "yemeni women's show jumping cup": "كأس اليمن لقفز الحواجز للسيدات",
    "yemeni women's show jumping racing cup": "كأس اليمن لسباق قفز الحواجز للسيدات",
    "yemeni women's silat cup": "كأس اليمن للسيلات للسيدات",
    "yemeni women's silat racing cup": "كأس اليمن لسباق سيلات للسيدات",
    "yemeni women's single skating cup": "كأس اليمن للتزلج الفردي على الجليد للسيدات",
    "yemeni women's single skating racing cup": "كأس اليمن لسباق التزلج الفردي على الجليد للسيدات",
    "yemeni women's skateboarding cup": "كأس اليمن للتزلج على اللوح للسيدات",
    "yemeni women's skateboarding racing cup": "كأس اليمن لسباق التزلج على اللوح للسيدات",
    "yemeni women's skating cup": "كأس اليمن للتزلج للسيدات",
    "yemeni women's skating racing cup": "كأس اليمن لسباق التزلج للسيدات",
    "yemeni women's skeleton cup": "كأس اليمن للزلاجات الصدرية للسيدات",
    "yemeni women's skeleton racing cup": "كأس اليمن لسباق الزلاجات الصدرية للسيدات",
    "yemeni women's ski flying cup": "كأس اليمن لتزلج طائر للسيدات",
    "yemeni women's ski flying racing cup": "كأس اليمن لسباق التزلج الطائر للسيدات",
    "yemeni women's ski jumping cup": "كأس اليمن للقفز التزلجي للسيدات",
    "yemeni women's ski jumping racing cup": "كأس اليمن لسباق القفز التزلجي للسيدات",
    "yemeni women's ski-orienteering cup": "كأس اليمن لسباق التزلج الموجه للسيدات",
    "yemeni women's skiing cup": "كأس اليمن للتزلج للسيدات",
    "yemeni women's skiing racing cup": "كأس اليمن لسباق التزلج للسيدات",
    "yemeni women's sledge hockey cup": "كأس اليمن لهوكي المزلجة للسيدات",
    "yemeni women's sledge hockey racing cup": "كأس اليمن لسباق هوكي المزلجة للسيدات",
    "yemeni women's snooker cup": "كأس اليمن للسنوكر للسيدات",
    "yemeni women's snooker racing cup": "كأس اليمن لسباق السنوكر للسيدات",
    "yemeni women's snowboarding cup": "كأس اليمن للتزلج على الثلوج للسيدات",
    "yemeni women's snowboarding racing cup": "كأس اليمن لسباق التزلج على الثلوج للسيدات",
    "yemeni women's soccer cup": "كأس اليمن لكرة القدم للسيدات",
    "yemeni women's soccer racing cup": "كأس اليمن لسباق كرة القدم للسيدات",
    "yemeni women's soft tennis cup": "كأس اليمن لكرة المضرب اللينة للسيدات",
    "yemeni women's soft tennis racing cup": "كأس اليمن لسباق كرة المضرب اللينة للسيدات",
    "yemeni women's softball cup": "كأس اليمن للكرة اللينة للسيدات",
    "yemeni women's softball racing cup": "كأس اليمن لسباق الكرة اللينة للسيدات",
    "yemeni women's speed skating cup": "كأس اليمن لتزلج السريع للسيدات",
    "yemeni women's speed skating racing cup": "كأس اليمن لسباق التزلج السريع للسيدات",
    "yemeni women's speed skiing cup": "كأس اليمن للتزلج السريع للسيدات",
    "yemeni women's speed skiing racing cup": "كأس اليمن لسباق التزلج السريع للسيدات",
    "yemeni women's sport climbing cup": "كأس اليمن للتسلق للسيدات",
    "yemeni women's sport climbing racing cup": "كأس اليمن لسباق التسلق للسيدات",
    "yemeni women's sprinting cup": "كأس اليمن للجري السريع للسيدات",
    "yemeni women's sprinting racing cup": "كأس اليمن لسباق الجري السريع للسيدات",
    "yemeni women's squash cup": "كأس اليمن للاسكواش للسيدات",
    "yemeni women's squash racing cup": "كأس اليمن لسباق اسكواش للسيدات",
    "yemeni women's submission wrestling cup": "كأس اليمن لمصارعة الخضوع للسيدات",
    "yemeni women's submission wrestling racing cup": "كأس اليمن لسباق مصارعة الخضوع للسيدات",
    "yemeni women's sumo cup": "كأس اليمن للسومو للسيدات",
    "yemeni women's sumo racing cup": "كأس اليمن لسباق السومو للسيدات",
    "yemeni women's surfing cup": "كأس اليمن للركمجة للسيدات",
    "yemeni women's surfing racing cup": "كأس اليمن لسباق الركمجة للسيدات",
    "yemeni women's swimming cup": "كأس اليمن للسباحة للسيدات",
    "yemeni women's swimming racing cup": "كأس اليمن لسباق السباحة للسيدات",
    "yemeni women's synchronised swimming cup": "كأس اليمن للسباحة المتزامنة للسيدات",
    "yemeni women's synchronised swimming racing cup": "كأس اليمن لسباق السباحة المتزامنة للسيدات",
    "yemeni women's synchronized swimming cup": "كأس اليمن للسباحة المتزامنة للسيدات",
    "yemeni women's synchronized swimming racing cup": "كأس اليمن لسباق السباحة المتزامنة للسيدات",
    "yemeni women's table tennis cup": "كأس اليمن لكرة الطاولة للسيدات",
    "yemeni women's table tennis racing cup": "كأس اليمن لسباق كرة الطاولة للسيدات",
    "yemeni women's taekwondo cup": "كأس اليمن للتايكوندو للسيدات",
    "yemeni women's taekwondo racing cup": "كأس اليمن لسباق التايكوندو للسيدات",
    "yemeni women's tennis cup": "كأس اليمن لكرة المضرب للسيدات",
    "yemeni women's tennis racing cup": "كأس اليمن لسباق كرة المضرب للسيدات",
    "yemeni women's time trial cup": "كأس اليمن لسباق الدراجات ضد الساعة للسيدات",
    "yemeni women's track and field cup": "كأس اليمن لسباقات المضمار والميدان للسيدات",
    "yemeni women's track cycling cup": "كأس اليمن لسباق الدراجات على المضمار للسيدات",
    "yemeni women's track-and-field athletics cup": "كأس اليمن لألعاب قوى المضمار والميدان للسيدات",
    "yemeni women's track-and-field athletics racing cup": "كأس اليمن لسباق ألعاب قوى المضمار والميدان للسيدات",
    "yemeni women's trampolining cup": "كأس اليمن لجمباز القفز للسيدات",
    "yemeni women's trampolining racing cup": "كأس اليمن لسباق جمباز القفز للسيدات",
    "yemeni women's triathlon cup": "كأس اليمن للسباق الثلاثي للسيدات",
    "yemeni women's triple jump cup": "كأس اليمن للقفز الثلاثي للسيدات",
    "yemeni women's triple jump racing cup": "كأس اليمن لسباق القفز الثلاثي للسيدات",
    "yemeni women's uiiu 22 formula e season racing cup": "كأس اليمن لسباق موسم فورمولا إي للسيدات",
    "yemeni women's underwater hockey cup": "كأس اليمن للهوكي تحت الماء للسيدات",
    "yemeni women's underwater hockey racing cup": "كأس اليمن لسباق هوكي تحت الماء للسيدات",
    "yemeni women's volleyball cup": "كأس اليمن لكرة الطائرة للسيدات",
    "yemeni women's volleyball racing cup": "كأس اليمن لسباق كرة الطائرة للسيدات",
    "yemeni women's water polo cup": "كأس اليمن لكرة الماء للسيدات",
    "yemeni women's water polo racing cup": "كأس اليمن لسباق كرة الماء للسيدات",
    "yemeni women's water skiing cup": "كأس اليمن لتزلج على الماء للسيدات",
    "yemeni women's water skiing racing cup": "كأس اليمن لسباق التزلج على الماء للسيدات",
    "yemeni women's waterskiing cup": "كأس اليمن للتزلج على الماء للسيدات",
    "yemeni women's waterskiing racing cup": "كأس اليمن لسباق التزلج على الماء للسيدات",
    "yemeni women's weightlifting cup": "كأس اليمن لرفع الأثقال للسيدات",
    "yemeni women's weightlifting racing cup": "كأس اليمن لسباق رفع الأثقال للسيدات",
    "yemeni women's wheelchair basketball cup": "كأس اليمن لكرة السلة على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair beach handball cup": "كأس اليمن لكرة اليد الشاطئية على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair curling cup": "كأس اليمن للكيرلنغ على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair fencing cup": "كأس اليمن لمبارزة سيف الشيش على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair handball cup": "كأس اليمن لكرة اليد على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair rugby cup": "كأس اليمن للرجبي على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair rugby league cup": "كأس اليمن لدوري الرجبي على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair tennis cup": "كأس اليمن لكرة المضرب على الكراسي المتحركة للسيدات",
    "yemeni women's windsurfing cup": "كأس اليمن لركوب القوارب الشراعية للسيدات",
    "yemeni women's windsurfing racing cup": "كأس اليمن لسباق ركوب القوارب الشراعية للسيدات",
    "yemeni women's wrestling cup": "كأس اليمن للمصارعة للسيدات",
    "yemeni women's wrestling racing cup": "كأس اليمن لسباق المصارعة للسيدات",
    "yemeni women's wushu cup": "كأس اليمن للووشو للسيدات",
    "yemeni women's wushu racing cup": "كأس اليمن لسباق ووشو للسيدات",
    "yemeni women's xiangqi cup": "كأس اليمن للشطرنج الصيني للسيدات",
    "yemeni women's xiangqi racing cup": "كأس اليمن لسباق الشطرنج الصيني للسيدات",
    "yemeni women's yacht racing cup": "كأس اليمن لسباقات اليخوت للسيدات",
    "yemeni wrestling cup": "كأس اليمن للمصارعة",
    "yemeni wrestling racing cup": "كأس اليمن لسباق المصارعة",
    "yemeni wushu cup": "كأس اليمن للووشو",
    "yemeni wushu racing cup": "كأس اليمن لسباق ووشو",
    "yemeni xiangqi cup": "كأس اليمن للشطرنج الصيني",
    "yemeni xiangqi racing cup": "كأس اليمن لسباق الشطرنج الصيني",
    "yemeni yacht racing cup": "كأس اليمن لسباقات اليخوت",
}


wheelchair_data_0 = {
    "american men wheelchair racers": "متسابقو كراسي متحركة أمريكيون",
    "australian men wheelchair racers": "متسابقو كراسي متحركة أستراليون",
    "austrian men wheelchair racers": "متسابقو كراسي متحركة نمساويون",
    "belgian men wheelchair racers": "متسابقو كراسي متحركة بلجيكيون",
    "british men wheelchair racers": "متسابقو كراسي متحركة بريطانيون",
    "brazilian men wheelchair racers": "متسابقو كراسي متحركة برازيليون",
    "canadian men wheelchair racers": "متسابقو كراسي متحركة كنديون",
    "english men wheelchair racers": "متسابقو كراسي متحركة إنجليز",
    "finnish men wheelchair racers": "متسابقو كراسي متحركة فنلنديون",
    "dutch men wheelchair racers": "متسابقو كراسي متحركة هولنديون",
    "chinese men wheelchair racers": "متسابقو كراسي متحركة صينيون",
    "french men wheelchair racers": "متسابقو كراسي متحركة فرنسيون",
    "gabonese men wheelchair racers": "متسابقو كراسي متحركة غابونيون",
    "german men wheelchair racers": "متسابقو كراسي متحركة ألمان",
    "irish men wheelchair racers": "متسابقو كراسي متحركة أيرلنديون",
    "israeli men wheelchair racers": "متسابقو كراسي متحركة إسرائيليون",
    "japanese men wheelchair racers": "متسابقو كراسي متحركة يابانيون",
    "mexican men wheelchair racers": "متسابقو كراسي متحركة مكسيكيون",
    "swiss men wheelchair racers": "متسابقو كراسي متحركة سويسريون",
    "welsh men wheelchair racers": "متسابقو كراسي متحركة ويلزيون",
}

data_1 = {
    "american men wheelchair racers": "متسابقو كراسي متحركة أمريكيون",
    "yemeni men basketball players": "لاعبو كرة سلة يمنيون",
    "yemeni men's basketball players": "لاعبو كرة سلة يمنيون",
    "chinese outdoor boxing clubs": "أندية بوكسينغ صينية في الهواء الطلق",
    "chinese outdoor boxing": "بوكسينغ صينية في الهواء الطلق",
    "chinese women's boxing": "بوكسينغ صينية للسيدات",
    "chinese indoor boxing": "بوكسينغ صينية داخل الصالات",
}

data_3 = {
    "chinese men's boxing championship": "بطولة الصين للبوكسينغ للرجال",
    "chinese amateur boxing championship": "بطولة الصين للبوكسينغ للهواة",
    "chinese amateur boxing championships": "بطولة الصين للبوكسينغ للهواة",
    "chinese championships boxing": "بطولة الصين للبوكسينغ",
    "chinese men's boxing championships": "بطولة الصين للبوكسينغ للرجال",
    "chinese men's boxing national team": "منتخب الصين للبوكسينغ للرجال",
    "chinese men's u23 national boxing team": "منتخب الصين للبوكسينغ تحت 23 سنة للرجال",
    "chinese boxing championship": "بطولة الصين للبوكسينغ",
    "chinese boxing championships": "بطولة الصين للبوكسينغ",
    "chinese boxing indoor championship": "بطولة الصين للبوكسينغ داخل الصالات",
    "chinese boxing indoor championships": "بطولة الصين للبوكسينغ داخل الصالات",
    "chinese boxing junior championships": "بطولة الصين للبوكسينغ للناشئين",
    "chinese boxing national team": "منتخب الصين للبوكسينغ",
    "chinese boxing u-13 championships": "بطولة الصين للبوكسينغ تحت 13 سنة",
    "chinese boxing u-14 championships": "بطولة الصين للبوكسينغ تحت 14 سنة",
    "chinese boxing u-15 championships": "بطولة الصين للبوكسينغ تحت 15 سنة",
    "chinese boxing u-16 championships": "بطولة الصين للبوكسينغ تحت 16 سنة",
    "chinese boxing u-17 championships": "بطولة الصين للبوكسينغ تحت 17 سنة",
    "chinese boxing u-18 championships": "بطولة الصين للبوكسينغ تحت 18 سنة",
    "chinese boxing u-19 championships": "بطولة الصين للبوكسينغ تحت 19 سنة",
    "chinese boxing u-20 championships": "بطولة الصين للبوكسينغ تحت 20 سنة",
    "chinese boxing u-21 championships": "بطولة الصين للبوكسينغ تحت 21 سنة",
    "chinese boxing u-23 championships": "بطولة الصين للبوكسينغ تحت 23 سنة",
    "chinese boxing u-24 championships": "بطولة الصين للبوكسينغ تحت 24 سنة",
    "chinese boxing u13 championships": "بطولة الصين للبوكسينغ تحت 13 سنة",
    "chinese boxing u14 championships": "بطولة الصين للبوكسينغ تحت 14 سنة",
    "chinese boxing u15 championships": "بطولة الصين للبوكسينغ تحت 15 سنة",
    "chinese boxing u16 championships": "بطولة الصين للبوكسينغ تحت 16 سنة",
    "chinese boxing u17 championships": "بطولة الصين للبوكسينغ تحت 17 سنة",
    "chinese boxing u18 championships": "بطولة الصين للبوكسينغ تحت 18 سنة",
    "chinese boxing u19 championships": "بطولة الصين للبوكسينغ تحت 19 سنة",
    "chinese boxing u20 championships": "بطولة الصين للبوكسينغ تحت 20 سنة",
    "chinese boxing u21 championships": "بطولة الصين للبوكسينغ تحت 21 سنة",
    "chinese boxing u23 championships": "بطولة الصين للبوكسينغ تحت 23 سنة",
    "chinese boxing u24 championships": "بطولة الصين للبوكسينغ تحت 24 سنة",
    "chinese open boxing": "الصين المفتوحة للبوكسينغ",
    "chinese outdoor boxing championship": "بطولة الصين للبوكسينغ في الهواء الطلق",
    "chinese outdoor boxing championships": "بطولة الصين للبوكسينغ في الهواء الطلق",
    "chinese women's boxing championship": "بطولة الصين للبوكسينغ للسيدات",
    "chinese women's boxing championships": "بطولة الصين للبوكسينغ للسيدات",
    "chinese youth boxing championship": "بطولة الصين للبوكسينغ للشباب",
    "chinese youth boxing championships": "بطولة الصين للبوكسينغ للشباب",
}


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_sport_lab_oioioi_load_1(category: str, expected: str) -> None:
    label2 = resolve_nats_sport_multi_v2(category)
    assert label2 == expected


@pytest.mark.parametrize("category, expected", data_3.items(), ids=data_3.keys())
@pytest.mark.fast
def test_sport_lab_oioioi_load_3(category: str, expected: str) -> None:
    label2 = resolve_nats_sport_multi_v2(category)
    assert label2 == expected


to_test = [
    ("test_sport_lab_oioioi_load_1", data_1, resolve_nats_sport_multi_v2),
    ("test_sport_lab_oioioi_load_3", data_3, resolve_nats_sport_multi_v2),
    ("oioioi_wheelchair_data_0", wheelchair_data_0, resolve_nats_sport_multi_v2),
    ("test_en_is_nat_ar_is_P17", en_is_nat_ar_is_P17_data, resolve_nats_sport_multi_v2),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)

    # add_result = {x: v for x, v in data.items() if x in diff_result and "" == diff_result.get(x)}
    # dump_diff(add_result, f"{name}_add")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



#!/usr/bin/python3
"""Integration tests for format_multi_data  """

import pytest

from ArWikiCats.translations_formats import (
    MultiDataFormatterBase,
    format_multi_data,
)

# Sample data for nationality translations
nationality_data = {
    "yemeni": "اليمن",
    "british": "المملكة المتحدة",
    "american": "الولايات المتحدة",
    "egyptian": "مصر",
}

# Sample data for sport translations
sport_data = {
    "football": "كرة القدم",
    "softball": "الكرة اللينة",
    "basketball": "كرة السلة",
    "volleyball": "الكرة الطائرة",
}

# Template data with both nationality and sport placeholders
formatted_data = {
    "{nat_en} {en_sport} teams": "فرق {sport_ar} {nat_ar}",
    "{nat_en} national {en_sport} teams": "منتخبات {nat_ar} ل{sport_ar}",
    "{nat_en} {en_sport} championships": "بطولات {nat_ar} في {sport_ar}",
    "ladies {nat_en} {en_sport} tour": "بطولة {nat_ar} ل{sport_ar} للسيدات",
    "{nat_en} {en_sport} players": "لاعبو {sport_ar} من {nat_ar}",
    "{nat_en} {en_sport} coaches": "مدربو {sport_ar} من {nat_ar}",
}


@pytest.fixture
def multi_bot() -> MultiDataFormatterBase:
    """Create a format_multi_data instance for testing."""
    return format_multi_data(
        formatted_data=formatted_data,
        data_list=nationality_data,
        key_placeholder="{nat_en}",
        value_placeholder="{nat_ar}",
        data_list2=sport_data,
        key2_placeholder="{en_sport}",
        value2_placeholder="{sport_ar}",
    )


class TestCountryBotNormalization:
    """Tests for FormatComparison Helper class."""

    def test_get_start_p17(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test get_st art_p17 method returns normalized category and key."""
        category = "yemeni football teams"
        key, new_category = multi_bot.country_bot.normalize_category_with_key(category)

        assert key == "yemeni"
        assert "{nat_en}" in new_category
        assert new_category == "{nat_en} football teams"


class TestFormatMultiDataInitialization:
    """Tests for format_multi_data initialization."""

    def test_initialization_with_defaults(self) -> None:
        """Test that format_multi_data initializes with default placeholders."""
        bot = format_multi_data(
            formatted_data={},
            data_list=nationality_data,
        )

        assert bot.country_bot.key_placeholder == "natar"
        assert bot.country_bot.value_placeholder == "natar"
        assert bot.other_bot.key_placeholder == "xoxo"
        assert bot.other_bot.value_placeholder == "xoxo"

    def test_initialization_with_custom_placeholders(self) -> None:
        """Test that format_multi_data initializes with custom placeholders."""
        bot = format_multi_data(
            formatted_data={},
            data_list=nationality_data,
            key_placeholder="COUNTRY",
            value_placeholder="{country}",
            data_list2=sport_data,
            key2_placeholder="SPORT",
            value2_placeholder="{sport_name}",
        )

        assert bot.country_bot.key_placeholder == "COUNTRY"
        assert bot.country_bot.value_placeholder == "{country}"
        assert bot.other_bot.key_placeholder == "SPORT"
        assert bot.other_bot.value_placeholder == "{sport_name}"

    def test_nat_bot_and_sport_bot_created(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test that nat_bot and other_bot are properly initialized."""
        assert multi_bot.country_bot is not None
        assert multi_bot.other_bot is not None


class TestNormalizeNatLabel:
    """Tests for normalize_nat_label method."""

    def test_normalize_nat_label_with_match(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test normalization when nationality is found."""
        category = "yemeni national football teams"
        result = multi_bot.normalize_nat_label(category)

        assert result == "{nat_en} national football teams"

    def test_normalize_nat_label_no_match(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test normalization when no nationality is found."""
        category = "some random category"
        result = multi_bot.normalize_nat_label(category)

        assert result == ""

    @pytest.mark.parametrize(
        "input_category,expected",
        [
            ("british football teams", "{nat_en} football teams"),
            ("american basketball players", "{nat_en} basketball players"),
            ("egyptian volleyball coaches", "{nat_en} volleyball coaches"),
        ],
    )
    def test_normalize_nat_label_various_nationalities(
        self, multi_bot: MultiDataFormatterBase, input_category: str, expected: str
    ) -> None:
        """Test normalization with various nationalities."""
        result = multi_bot.normalize_nat_label(input_category)
        assert result == expected


class TestNormalizeSportLabel:
    """Tests for normalize_other_label method."""

    def test_normalize_sport_label_with_match(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test normalization when sport is found."""
        category = "yemeni national football teams"
        result = multi_bot.normalize_other_label(category)

        assert result == "yemeni national {en_sport} teams"

    def test_normalize_sport_label_no_match(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test normalization when no sport is found."""
        category = "some random category"
        result = multi_bot.normalize_other_label(category)

        assert result == ""

    @pytest.mark.parametrize(
        "input_category,expected",
        [
            ("yemeni football teams", "yemeni {en_sport} teams"),
            ("british basketball players", "british {en_sport} players"),
            ("american volleyball coaches", "american {en_sport} coaches"),
        ],
    )
    def test_normalize_sport_label_various_sports(
        self, multi_bot: MultiDataFormatterBase, input_category: str, expected: str
    ) -> None:
        """Test normalization with various sports."""
        result = multi_bot.normalize_other_label(input_category)
        assert result == expected


class TestNormalizeBoth:
    """Tests for normalize_both method."""

    def test_normalize_both_with_matches(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test normalization when both nationality and sport are found."""
        category = "british softball championships"
        result = multi_bot.normalize_both(category)

        assert result == "{nat_en} {en_sport} championships"

    def test_normalize_both_order_matters(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test that nationality is normalized first, then sport."""
        category = "yemeni football teams"
        result = multi_bot.normalize_both(category)

        # Should normalize nationality first, then sport
        assert result == "{nat_en} {en_sport} teams"

    @pytest.mark.parametrize(
        "input_category,expected",
        [
            ("british softball championships", "{nat_en} {en_sport} championships"),
            ("yemeni football teams", "{nat_en} {en_sport} teams"),
            ("american basketball players", "{nat_en} {en_sport} players"),
            ("egyptian volleyball coaches", "{nat_en} {en_sport} coaches"),
        ],
    )
    def test_normalize_both_various_combinations(
        self, multi_bot: MultiDataFormatterBase, input_category: str, expected: str
    ) -> None:
        """Test normalization with various nationality-sport combinations."""
        result = multi_bot.normalize_both(input_category)
        assert result == expected


class TestCreateNatLabel:
    """Tests for create_nat_label method."""

    def test_create_nat_label_with_match(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test creating nationality label when match is found."""
        category = "yemeni football teams"
        result = multi_bot.create_nat_label(category)
        # With the current `formatted_data`, `nat_bot` won't find a template
        # and will return an empty string.
        assert result == ""

    def test_create_nat_label_caching(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test that create_nat_label uses LRU cache."""
        category = "yemeni football teams"
        result1 = multi_bot.create_nat_label(category)
        result2 = multi_bot.create_nat_label(category)

        # Should return the same cached result
        assert result1 == result2


class TestCreateLabel:
    """Tests for create_label method."""

    def test_create_label_full_match(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test creating label when both nationality and sport match."""
        category = "yemeni football teams"
        result = multi_bot.create_label(category)

        expected = "فرق كرة القدم اليمن"
        assert result == expected

    def test_create_label_no_nationality(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test creating label when nationality is not found."""
        category = "unknown football teams"
        result = multi_bot.create_label(category)

        assert result == ""

    def test_create_label_no_template(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test creating label when template doesn't exist."""
        category = "yemeni football something"
        result = multi_bot.create_label(category)

        # Template "{nat_en} {en_sport} something" doesn't exist in formatted_data
        assert result == ""

    @pytest.mark.parametrize(
        "input_category,expected",
        [
            ("yemeni football teams", "فرق كرة القدم اليمن"),
            ("british softball championships", "بطولات المملكة المتحدة في الكرة اللينة"),
            ("american basketball players", "لاعبو كرة السلة من الولايات المتحدة"),
            ("egyptian volleyball coaches", "مدربو الكرة الطائرة من مصر"),
        ],
    )
    def test_create_label_various_combinations(
        self, multi_bot: MultiDataFormatterBase, input_category: str, expected: str
    ) -> None:
        """Test creating labels with various nationality-sport combinations."""
        result = multi_bot.create_label(input_category)
        assert result == expected

    def test_create_label_with_national_teams(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test creating label for national teams pattern."""
        category = "yemeni national football teams"
        result = multi_bot.create_label(category)

        expected = "منتخبات اليمن لكرة القدم"
        assert result == expected

    @pytest.mark.skip2
    def test_create_label_ladies_tour(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test creating label for ladies tour pattern."""
        category = "ladies british softball tour"
        result = multi_bot.create_label(category)

        expected = "بطولة المملكة المتحدة للكرة اللينة للسيدات"
        assert result == expected

    def test_create_label_caching(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test that create_label uses LRU cache."""
        category = "yemeni football teams"
        result1 = multi_bot.create_label(category)
        result2 = multi_bot.create_label(category)

        # Should return the same cached result
        assert result1 == result2
        assert result1 == "فرق كرة القدم اليمن"


class TestEdgeCases:
    """Tests for edge cases and error handling."""

    def test_empty_category(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test with empty category string."""
        result = multi_bot.create_label("")
        assert result == ""

    def test_category_with_only_nationality(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test with category containing only nationality."""
        result = multi_bot.create_label("yemeni")
        assert result == ""

    def test_category_with_only_sport(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test with category containing only sport."""
        result = multi_bot.create_label("football")
        assert result == ""

    @pytest.mark.skip2
    def test_case_insensitive_matching(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test that matching is case-insensitive."""
        result1 = multi_bot.create_label("Yemeni Football Teams")
        result2 = multi_bot.create_label("yemeni football teams")
        result3 = multi_bot.create_label("YEMENI FOOTBALL TEAMS")

        # All should produce the same result
        assert result1 == result2 == result3
        assert result1 == "فرق كرة القدم اليمن"

    def test_with_extra_spaces(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test handling of extra spaces in category."""
        result = multi_bot.create_label("yemeni  football  teams")
        # Should still work despite extra spaces
        assert result == "فرق كرة القدم اليمن"


class TestWithTextAfterAndBefore:
    """Tests for format_multi_data with text_after and text_before parameters."""

    @pytest.mark.skip2
    def test_with_text_after(self) -> None:
        """Test format_multi_data with text_after parameter."""
        bot = format_multi_data(
            formatted_data={"{nat_en} sports {en_sport} teams": "فرق {sport_ar} {nat_ar}"},
            data_list={"yemeni": "اليمن"},
            key_placeholder="{nat_en}",
            value_placeholder="{nat_ar}",
            data_list2={"football": "كرة القدم"},
            key2_placeholder="{en_sport}",
            value2_placeholder="{sport_ar}",
            text_before="",
            text_after=" sports",
        )

        category = "yemenian football teams"
        result = bot.create_label(category)

        assert result == "فرق كرة القدم اليمن"

    @pytest.mark.skip2
    def test_with_text_before(self) -> None:
        """Test format_multi_data with text_before parameter."""
        bot = format_multi_data(
            formatted_data={"{nat_en} the {en_sport} teams": "فرق {sport_ar} {nat_ar}"},
            data_list={"yemeni": "اليمن"},
            key_placeholder="{nat_en}",
            value_placeholder="{nat_ar}",
            data_list2={"football": "كرة القدم"},
            key2_placeholder="{en_sport}",
            value2_placeholder="{sport_ar}",
            text_before="the ",
            text_after="",
        )

        category = "the yemeni football teams"
        result = bot.create_label(category)

        assert result == "فرق كرة القدم اليمن"


@pytest.mark.slow
class TestPerformance:
    """Performance tests for caching behavior."""

    def test_cache_effectiveness(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test that LRU cache improves performance on repeated calls."""
        category = "yemeni football teams"

        # First call - cache miss
        result1 = multi_bot.create_label(category)

        # Subsequent calls - cache hits
        for _ in range(100):
            result = multi_bot.create_label(category)
            assert result == result1

    def test_multiple_categories_caching(self, multi_bot: MultiDataFormatterBase) -> None:
        """Test caching with multiple different categories."""
        categories = [
            "yemeni football teams",
            "british softball championships",
            "american basketball players",
        ]

        # Cache all categories
        results = [multi_bot.create_label(cat) for cat in categories]

        # Verify cached results match
        for i, cat in enumerate(categories):
            assert multi_bot.create_label(cat) == results[i]
